/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<clappingexercisecontroller.h>)
#  include <clappingexercisecontroller.h>
#endif
#if __has_include(<core.h>)
#  include <core.h>
#endif
#if __has_include(<exercisecatalogcontroller.h>)
#  include <exercisecatalogcontroller.h>
#endif
#if __has_include(<exercisesessioncontroller.h>)
#  include <exercisesessioncontroller.h>
#endif
#if __has_include(<instrumentcatalogcontroller.h>)
#  include <instrumentcatalogcontroller.h>
#endif
#if __has_include(<interfaceqmltypes.h>)
#  include <interfaceqmltypes.h>
#endif
#if __has_include(<pianokeyboardcontroller.h>)
#  include <pianokeyboardcontroller.h>
#endif
#if __has_include(<sheetmusiccontroller.h>)
#  include <sheetmusiccontroller.h>
#endif
#if __has_include(<singingexercisecontroller.h>)
#  include <singingexercisecontroller.h>
#endif
#if __has_include(<smuflmetadata.h>)
#  include <smuflmetadata.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_minuet()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<Minuet::ClappingExerciseController>("org.kde.minuet", 1);
    qmlRegisterTypesAndRevisions<Minuet::Core>("org.kde.minuet", 1);
    qmlRegisterTypesAndRevisions<Minuet::ExerciseCatalogController>("org.kde.minuet", 1);
    qmlRegisterTypesAndRevisions<Minuet::ExerciseSessionController>("org.kde.minuet", 1);
    qmlRegisterEnum<Minuet::ExerciseSessionController::StatusRole>("Minuet::ExerciseSessionController::StatusRole");
    qmlRegisterTypesAndRevisions<Minuet::InstrumentCatalogController>("org.kde.minuet", 1);
    qmlRegisterTypesAndRevisions<Minuet::InterfaceQmlTypes::IMicrophoneInputControllerForeign>("org.kde.minuet", 1);
    qmlRegisterEnum<Minuet::IMicrophoneInputController::Preset>("Minuet::IMicrophoneInputController::Preset");
    qmlRegisterEnum<Minuet::IMicrophoneInputController::AnalysisMode>("Minuet::IMicrophoneInputController::AnalysisMode");
    qmlRegisterEnum<Minuet::IMicrophoneInputController::VoiceClass>("Minuet::IMicrophoneInputController::VoiceClass");
    qmlRegisterEnum<Minuet::IMicrophoneInputController::PitchMethod>("Minuet::IMicrophoneInputController::PitchMethod");
    qmlRegisterEnum<Minuet::IMicrophoneInputController::OnsetMethod>("Minuet::IMicrophoneInputController::OnsetMethod");
    qmlRegisterTypesAndRevisions<Minuet::InterfaceQmlTypes::ISoundControllerForeign>("org.kde.minuet", 1);
    qmlRegisterEnum<Minuet::ISoundController::State>("Minuet::ISoundController::State");
    qmlRegisterTypesAndRevisions<Minuet::PianoKeyboardController>("org.kde.minuet", 1);
    qmlRegisterTypesAndRevisions<Minuet::SheetMusicController>("org.kde.minuet", 1);
    qmlRegisterTypesAndRevisions<Minuet::SingingExerciseController>("org.kde.minuet", 1);
    qmlRegisterTypesAndRevisions<Minuet::SmuflMetadata>("org.kde.minuet", 1);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.minuet", 1, 0);
}

static const QQmlModuleRegistration orgkdeminuetRegistration("org.kde.minuet", qml_register_types_org_kde_minuet);
