/****************************************************************************
** Meta object code from reading C++ file 'core.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../minuet-26.08.0/src/app/core.h"
#include "exercisecatalogcontroller.h"
#include "clappingexercisecontroller.h"
#include "exercisesessioncontroller.h"
#include "instrumentcatalogcontroller.h"
#include "pianokeyboardcontroller.h"
#include "settingscontroller.h"
#include "sheetmusiccontroller.h"
#include "singingexercisecontroller.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'core.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Minuet4CoreE_t {};
} // unnamed namespace

template <> constexpr inline auto Minuet::Core::qt_create_metaobjectdata<qt_meta_tag_ZN6Minuet4CoreE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Minuet::Core",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "soundControllerChanged",
        "",
        "Minuet::ISoundController*",
        "newSoundController",
        "microphoneInputControllerChanged",
        "Minuet::IMicrophoneInputController*",
        "newMicrophoneInputController",
        "stopExerciseActivity",
        "soundController",
        "microphoneInputController",
        "settingsController",
        "Minuet::SettingsController*",
        "sheetMusicController",
        "Minuet::SheetMusicController*",
        "exerciseCatalogController",
        "Minuet::ExerciseCatalogController*",
        "clappingExerciseController",
        "Minuet::ClappingExerciseController*",
        "instrumentCatalogController",
        "Minuet::InstrumentCatalogController*",
        "pianoKeyboardController",
        "Minuet::PianoKeyboardController*",
        "exerciseSessionController",
        "Minuet::ExerciseSessionController*",
        "singingExerciseController",
        "Minuet::SingingExerciseController*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'soundControllerChanged'
        QtMocHelpers::SignalData<void(Minuet::ISoundController *)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'microphoneInputControllerChanged'
        QtMocHelpers::SignalData<void(Minuet::IMicrophoneInputController *)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Method 'stopExerciseActivity'
        QtMocHelpers::MethodData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'soundController'
        QtMocHelpers::PropertyData<Minuet::ISoundController*>(13, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'microphoneInputController'
        QtMocHelpers::PropertyData<Minuet::IMicrophoneInputController*>(14, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'settingsController'
        QtMocHelpers::PropertyData<Minuet::SettingsController*>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'sheetMusicController'
        QtMocHelpers::PropertyData<Minuet::SheetMusicController*>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'exerciseCatalogController'
        QtMocHelpers::PropertyData<Minuet::ExerciseCatalogController*>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'clappingExerciseController'
        QtMocHelpers::PropertyData<Minuet::ClappingExerciseController*>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'instrumentCatalogController'
        QtMocHelpers::PropertyData<Minuet::InstrumentCatalogController*>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'pianoKeyboardController'
        QtMocHelpers::PropertyData<Minuet::PianoKeyboardController*>(25, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'exerciseSessionController'
        QtMocHelpers::PropertyData<Minuet::ExerciseSessionController*>(27, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'singingExerciseController'
        QtMocHelpers::PropertyData<Minuet::SingingExerciseController*>(29, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Core, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Minuet::Core::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Minuet4CoreE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Minuet4CoreE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Minuet4CoreE_t>.metaTypes,
    nullptr
} };

void Minuet::Core::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Core *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->soundControllerChanged((*reinterpret_cast<std::add_pointer_t<Minuet::ISoundController*>>(_a[1]))); break;
        case 1: _t->microphoneInputControllerChanged((*reinterpret_cast<std::add_pointer_t<Minuet::IMicrophoneInputController*>>(_a[1]))); break;
        case 2: _t->stopExerciseActivity(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Minuet::ISoundController* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Minuet::IMicrophoneInputController* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Core::*)(Minuet::ISoundController * )>(_a, &Core::soundControllerChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(Minuet::IMicrophoneInputController * )>(_a, &Core::microphoneInputControllerChanged, 1))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Minuet::IMicrophoneInputController* >(); break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Minuet::ISoundController* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Minuet::ISoundController**>(_v) = _t->soundController(); break;
        case 1: *reinterpret_cast<Minuet::IMicrophoneInputController**>(_v) = _t->microphoneInputController(); break;
        case 2: *reinterpret_cast<Minuet::SettingsController**>(_v) = _t->settingsController(); break;
        case 3: *reinterpret_cast<Minuet::SheetMusicController**>(_v) = _t->sheetMusicController(); break;
        case 4: *reinterpret_cast<Minuet::ExerciseCatalogController**>(_v) = _t->exerciseCatalogController(); break;
        case 5: *reinterpret_cast<Minuet::ClappingExerciseController**>(_v) = _t->clappingExerciseController(); break;
        case 6: *reinterpret_cast<Minuet::InstrumentCatalogController**>(_v) = _t->instrumentCatalogController(); break;
        case 7: *reinterpret_cast<Minuet::PianoKeyboardController**>(_v) = _t->pianoKeyboardController(); break;
        case 8: *reinterpret_cast<Minuet::ExerciseSessionController**>(_v) = _t->exerciseSessionController(); break;
        case 9: *reinterpret_cast<Minuet::SingingExerciseController**>(_v) = _t->singingExerciseController(); break;
        default: break;
        }
    }
}

const QMetaObject *Minuet::Core::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Minuet::Core::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Minuet4CoreE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Minuet::Core::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void Minuet::Core::soundControllerChanged(Minuet::ISoundController * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Minuet::Core::microphoneInputControllerChanged(Minuet::IMicrophoneInputController * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
