// This file is autogenerated. Changes will be overwritten.
#include "EWIEGA46WW/moc_clappingexercisecontroller.cpp"
#include "EWIEGA46WW/moc_exercisecatalogcontroller.cpp"
#include "EWIEGA46WW/moc_exercisesessioncontroller.cpp"
#include "EWIEGA46WW/moc_instrumentcatalogcontroller.cpp"
#include "EWIEGA46WW/moc_interfaceqmltypes.cpp"
#include "EWIEGA46WW/moc_pianokeyboardcontroller.cpp"
#include "EWIEGA46WW/moc_sheetmusiccontroller.cpp"
#include "EWIEGA46WW/moc_singingexercisecontroller.cpp"
#include "EWIEGA46WW/moc_smuflmetadata.cpp"
