/****************************************************************************
** Meta object code from reading C++ file 'clappingexercisecontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../minuet-26.08.0/src/app/clappingexercisecontroller.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'clappingexercisecontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Minuet26ClappingExerciseControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto Minuet::ClappingExerciseController::qt_create_metaobjectdata<qt_meta_tag_ZN6Minuet26ClappingExerciseControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Minuet::ClappingExerciseController",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "ClappingExerciseController is provided by Core",
        "createQuestion",
        "QVariantMap",
        "",
        "QVariantList",
        "selectedOptions",
        "beatMs",
        "evaluate",
        "expectedOnsets",
        "figureStates",
        "performedOnsets",
        "elapsedMs",
        "toleranceMs",
        "addPerformedOnset",
        "figureIndexForElapsed",
        "timelineIndex",
        "totalDurationMs",
        "score"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'createQuestion'
        QtMocHelpers::MethodData<QVariantMap(const QVariantList &, double) const>(7, 9, QMC::AccessPublic, 0x80000000 | 8, {{
            { 0x80000000 | 10, 11 }, { QMetaType::Double, 12 },
        }}),
        // Method 'evaluate'
        QtMocHelpers::MethodData<QVariantMap(const QVariantList &, const QVariantList &, const QVariantList &, double, double) const>(13, 9, QMC::AccessPublic, 0x80000000 | 8, {{
            { 0x80000000 | 10, 14 }, { 0x80000000 | 10, 15 }, { 0x80000000 | 10, 16 }, { QMetaType::Double, 17 },
            { QMetaType::Double, 18 },
        }}),
        // Method 'addPerformedOnset'
        QtMocHelpers::MethodData<QVariantList(const QVariantList &, double) const>(19, 9, QMC::AccessPublic, 0x80000000 | 10, {{
            { 0x80000000 | 10, 16 }, { QMetaType::Double, 17 },
        }}),
        // Method 'figureIndexForElapsed'
        QtMocHelpers::MethodData<int(const QVariantList &, double, double) const>(20, 9, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 10, 15 }, { QMetaType::Double, 17 }, { QMetaType::Double, 18 },
        }}),
        // Method 'timelineIndex'
        QtMocHelpers::MethodData<int(const QVariantList &, double, double) const>(21, 9, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 10, 15 }, { QMetaType::Double, 17 }, { QMetaType::Double, 18 },
        }}),
        // Method 'totalDurationMs'
        QtMocHelpers::MethodData<double(const QVariantList &) const>(22, 9, QMC::AccessPublic, QMetaType::Double, {{
            { 0x80000000 | 10, 15 },
        }}),
        // Method 'score'
        QtMocHelpers::MethodData<int(const QVariantList &, const QVariantList &, double) const>(23, 9, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 10, 14 }, { 0x80000000 | 10, 16 }, { QMetaType::Double, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<ClappingExerciseController, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Minuet::ClappingExerciseController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Minuet26ClappingExerciseControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Minuet26ClappingExerciseControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Minuet26ClappingExerciseControllerE_t>.metaTypes,
    nullptr
} };

void Minuet::ClappingExerciseController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ClappingExerciseController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QVariantMap _r = _t->createQuestion((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 1: { QVariantMap _r = _t->evaluate((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 2: { QVariantList _r = _t->addPerformedOnset((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 3: { int _r = _t->figureIndexForElapsed((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 4: { int _r = _t->timelineIndex((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 5: { double _r = _t->totalDurationMs((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 6: { int _r = _t->score((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *Minuet::ClappingExerciseController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Minuet::ClappingExerciseController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Minuet26ClappingExerciseControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Minuet::ClappingExerciseController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
