/****************************************************************************
** Meta object code from reading C++ file 'aubioanalysisworker.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../minuet-26.08.0/src/plugins/aubiomicrophoneinputcontroller/aubioanalysisworker.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'aubioanalysisworker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19AubioAnalysisWorkerE_t {};
} // unnamed namespace

template <> constexpr inline auto AubioAnalysisWorker::qt_create_metaobjectdata<qt_meta_tag_ZN19AubioAnalysisWorkerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AubioAnalysisWorker",
        "initializationFailed",
        "",
        "generation",
        "message",
        "chunkProcessed",
        "qsizetype",
        "byteCount",
        "statsUpdated",
        "processedSamples",
        "audioLevel",
        "peakLevel",
        "stablePitchFrames",
        "pitchResult",
        "seconds",
        "voiced",
        "frequencyHz",
        "confidence",
        "reason",
        "onsetResult",
        "strength",
        "noiseCalibrationFinished",
        "noiseFloor",
        "drained"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'initializationFailed'
        QtMocHelpers::SignalData<void(quint64, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'chunkProcessed'
        QtMocHelpers::SignalData<void(quint64, qsizetype)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 6, 7 },
        }}),
        // Signal 'statsUpdated'
        QtMocHelpers::SignalData<void(quint64, quint64, double, double, int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::ULongLong, 9 }, { QMetaType::Double, 10 }, { QMetaType::Double, 11 },
            { QMetaType::Int, 12 },
        }}),
        // Signal 'pitchResult'
        QtMocHelpers::SignalData<void(quint64, double, bool, double, double, const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::Double, 14 }, { QMetaType::Bool, 15 }, { QMetaType::Double, 16 },
            { QMetaType::Double, 17 }, { QMetaType::QString, 18 },
        }}),
        // Signal 'onsetResult'
        QtMocHelpers::SignalData<void(quint64, double, double)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::Double, 14 }, { QMetaType::Double, 20 },
        }}),
        // Signal 'noiseCalibrationFinished'
        QtMocHelpers::SignalData<void(quint64, double)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::Double, 22 },
        }}),
        // Signal 'drained'
        QtMocHelpers::SignalData<void(quint64)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AubioAnalysisWorker, qt_meta_tag_ZN19AubioAnalysisWorkerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AubioAnalysisWorker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19AubioAnalysisWorkerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19AubioAnalysisWorkerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19AubioAnalysisWorkerE_t>.metaTypes,
    nullptr
} };

void AubioAnalysisWorker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AubioAnalysisWorker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->initializationFailed((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->chunkProcessed((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qsizetype>>(_a[2]))); break;
        case 2: _t->statsUpdated((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint64>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 3: _t->pitchResult((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6]))); break;
        case 4: _t->onsetResult((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3]))); break;
        case 5: _t->noiseCalibrationFinished((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 6: _t->drained((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AubioAnalysisWorker::*)(quint64 , const QString & )>(_a, &AubioAnalysisWorker::initializationFailed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AubioAnalysisWorker::*)(quint64 , qsizetype )>(_a, &AubioAnalysisWorker::chunkProcessed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AubioAnalysisWorker::*)(quint64 , quint64 , double , double , int )>(_a, &AubioAnalysisWorker::statsUpdated, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AubioAnalysisWorker::*)(quint64 , double , bool , double , double , const QString & )>(_a, &AubioAnalysisWorker::pitchResult, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AubioAnalysisWorker::*)(quint64 , double , double )>(_a, &AubioAnalysisWorker::onsetResult, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AubioAnalysisWorker::*)(quint64 , double )>(_a, &AubioAnalysisWorker::noiseCalibrationFinished, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AubioAnalysisWorker::*)(quint64 )>(_a, &AubioAnalysisWorker::drained, 6))
            return;
    }
}

const QMetaObject *AubioAnalysisWorker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AubioAnalysisWorker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19AubioAnalysisWorkerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AubioAnalysisWorker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void AubioAnalysisWorker::initializationFailed(quint64 _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void AubioAnalysisWorker::chunkProcessed(quint64 _t1, qsizetype _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void AubioAnalysisWorker::statsUpdated(quint64 _t1, quint64 _t2, double _t3, double _t4, int _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 3
void AubioAnalysisWorker::pitchResult(quint64 _t1, double _t2, bool _t3, double _t4, double _t5, const QString & _t6)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3, _t4, _t5, _t6);
}

// SIGNAL 4
void AubioAnalysisWorker::onsetResult(quint64 _t1, double _t2, double _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3);
}

// SIGNAL 5
void AubioAnalysisWorker::noiseCalibrationFinished(quint64 _t1, double _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void AubioAnalysisWorker::drained(quint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
