/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x1,0xad,
  0x28,
  0xb5,0x2f,0xfd,0x60,0xd0,0x4,0x1d,0xd,0x0,0x46,0x52,0x37,0x1e,0x40,0x73,0x73,
  0xf,0x22,0x61,0xd9,0x16,0xd1,0x77,0xc9,0x56,0x8e,0xa0,0xe7,0x2b,0x99,0x52,0x77,
  0x50,0x7d,0x22,0x38,0xc7,0x13,0x51,0xd4,0x24,0x8d,0x8,0x30,0x0,0x2d,0x0,0x2d,
  0x0,0xf9,0x22,0x63,0x3,0xe7,0x1,0x40,0x81,0x67,0x35,0x23,0x67,0xad,0x25,0x3d,
  0x5e,0xab,0x2f,0x4b,0xf0,0xbc,0x57,0xfe,0x9c,0x3,0xa9,0xea,0x2,0x3d,0x5c,0x59,
  0xbd,0xdb,0xb4,0xd3,0x8f,0xab,0x15,0xf4,0x66,0x81,0xa4,0xc7,0xcf,0xa9,0xd8,0xb8,
  0xa,0x8e,0x1f,0xd3,0x88,0x4a,0xa6,0x93,0xcb,0x87,0x68,0x4a,0x1d,0xa2,0x61,0x2,
  0x53,0x2a,0x2e,0x40,0x69,0xb5,0xfb,0x90,0x76,0xb6,0x89,0x69,0xd5,0x5b,0xd1,0x50,
  0x19,0xcb,0xda,0xb,0xf6,0x7e,0xd9,0x55,0xcc,0xde,0xfb,0xd1,0x86,0x5,0x2c,0x9f,
  0x23,0xee,0xa3,0x5,0x2f,0xa5,0xbb,0xc4,0x94,0x81,0xb4,0xa,0x79,0x6f,0xf9,0x44,
  0xef,0x7b,0x79,0xc1,0x67,0xae,0x12,0xe7,0x92,0x2a,0x1c,0x2a,0x7b,0xd7,0x1c,0x32,
  0xf9,0xc,0xd4,0x37,0x1d,0x1d,0xdd,0x2a,0xbe,0x3c,0x5,0x8e,0x63,0x61,0x1a,0x1f,
  0xfd,0x78,0x60,0xdb,0xbb,0xb7,0x88,0x29,0x8c,0x55,0xff,0x13,0x6c,0xcd,0x23,0xf9,
  0x22,0x26,0xdf,0x5b,0xa7,0xc9,0x31,0xd9,0xac,0xb1,0x32,0x57,0xc,0x6f,0xea,0xe6,
  0xb,0xb,0x4b,0x8a,0xd0,0x38,0x3a,0xd3,0xe,0x5d,0xa0,0xa1,0xce,0x8,0x9,0x5,
  0x49,0x93,0x94,0x1a,0x3,0x20,0x44,0xa8,0xd8,0x92,0x7,0x5c,0x48,0xe4,0x59,0x10,
  0xff,0x6d,0x5b,0xf4,0x2,0x80,0x1b,0x66,0xcd,0xdb,0x3b,0x5f,0x86,0x3a,0xba,0x89,
  0x22,0xaf,0x1b,0xaf,0x57,0xa8,0xa5,0xa1,0x5,0xf2,0xe0,0xd5,0x91,0xd,0x93,0x56,
  0x2,0x57,0x99,0x48,0xcb,0xfe,0x50,0x7c,0x12,0xdd,0xa4,0x82,0x87,0x30,0x48,0x90,
  0x7a,0xb4,0x29,0x74,0x21,0x84,0x3a,0xe6,0x93,0x99,0x4f,0xee,0x62,0xe0,0x2b,0x4f,
  0x1e,0xa6,0x82,0x6e,0x23,0x70,0x24,0x7a,0x2c,0x56,0xfc,0x3a,0x92,0x87,0xe2,0xb4,
  0x7c,0x2c,0x8e,0xf2,0xfa,0xc,0x65,0xa5,0x50,0x2,0xb8,0xe1,0xab,0x41,0x3f,0x40,
  0xc,0x26,0x20,0xe2,0x78,0xe3,0xe7,0x1d,0x42,0xb,0xc6,0x38,0xbc,0x43,0x53,0xf3,
  0x12,0x6,0xb,0x7d,0xf1,0x69,0x8c,0x29,0x7e,0x18,0x41,0x5c,0x88,0xab,0x59,0xf9,
  0x8,0xa4,0x28,0x14,0x8e,0x8a,0xc5,0x4f,0x60,0xb7,0x18,0xdf,0x63,0xd,0x17,0x7c,
  0xd8,0x50,0x1c,0xf3,0xf5,0x59,0x99,0x27,0xcf,0x24,0x16,0x9f,0x80,0x1,0x80,0x8,
  0x68,0x18,0x77,0x81,0x1d,0x9,0x64,0xc,0xfa,0x33,0xf0,0x2a,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // kde
  0x0,0x3,
  0x0,0x0,0x71,0xa5,
  0x0,0x6b,
  0x0,0x64,0x0,0x65,
    // minuet
  0x0,0x6,
  0x7,0x40,0x5b,0xc4,
  0x0,0x6d,
  0x0,0x69,0x0,0x6e,0x0,0x75,0x0,0x65,0x0,0x74,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0xa0,0x1a,0x8b,0x93,0x70,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0xa0,0x1a,0x8b,0x93,0x70,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0xa0,0x1a,0x8b,0x93,0x70,
  // :/qt/qml/org
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0xa0,0x1a,0x8b,0x93,0x70,
  // :/qt/qml/org/kde
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0xa0,0x1a,0x8b,0x93,0x70,
  // :/qt/qml/org/kde/minuet
  0x0,0x0,0x0,0x2e,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x6,
0x0,0x0,0x1,0xa0,0x1a,0x8b,0x93,0x70,
  // :/qt/qml/org/kde/minuet/qmldir
  0x0,0x0,0x0,0x40,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0xa0,0x1a,0x8b,0x93,0x70,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_minuet)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_minuet)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_minuet)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_minuet)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_minuet)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_minuet)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
