/****************************************************************************
** Meta object code from reading C++ file 'exercisecatalogcontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../minuet-26.08.0/src/app/exercisecatalogcontroller.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'exercisecatalogcontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Minuet25ExerciseCatalogControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto Minuet::ExerciseCatalogController::qt_create_metaobjectdata<qt_meta_tag_ZN6Minuet25ExerciseCatalogControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Minuet::ExerciseCatalogController",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "ExerciseCatalogController is provided by Core",
        "iconNameForExercise",
        "",
        "QVariantMap",
        "exercise",
        "inheritedIconName",
        "actionIconNameForExercise",
        "collectExercises",
        "QVariantList",
        "exercises",
        "exerciseDescription",
        "normalizedText",
        "text",
        "actionMatches",
        "actionText",
        "searchText",
        "exerciseMatchesSearch",
        "practiceModeForExercise",
        "exerciseForInputMode",
        "inputMode",
        "practiceMode",
        "QJsonArray"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'iconNameForExercise'
        QtMocHelpers::MethodData<QString(const QVariantMap &, const QString &) const>(7, 8, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 9, 10 }, { QMetaType::QString, 11 },
        }}),
        // Method 'actionIconNameForExercise'
        QtMocHelpers::MethodData<QString(const QVariantMap &, const QString &) const>(12, 8, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 9, 10 }, { QMetaType::QString, 11 },
        }}),
        // Method 'collectExercises'
        QtMocHelpers::MethodData<QVariantList(const QVariantList &, const QString &) const>(13, 8, QMC::AccessPublic, 0x80000000 | 14, {{
            { 0x80000000 | 14, 15 }, { QMetaType::QString, 11 },
        }}),
        // Method 'exerciseDescription'
        QtMocHelpers::MethodData<QString(const QVariantMap &) const>(16, 8, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Method 'normalizedText'
        QtMocHelpers::MethodData<QString(const QString &) const>(17, 8, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 18 },
        }}),
        // Method 'actionMatches'
        QtMocHelpers::MethodData<bool(const QString &, const QString &) const>(19, 8, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
        }}),
        // Method 'exerciseMatchesSearch'
        QtMocHelpers::MethodData<bool(const QVariantMap &, const QString &, const QString &) const>(22, 8, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 9, 10 }, { QMetaType::QString, 21 }, { QMetaType::QString, 11 },
        }}),
        // Method 'practiceModeForExercise'
        QtMocHelpers::MethodData<QString(const QVariantMap &) const>(23, 8, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Method 'exerciseForInputMode'
        QtMocHelpers::MethodData<QVariantMap(const QVariantMap &, const QString &, const QString &) const>(24, 8, QMC::AccessPublic, 0x80000000 | 9, {{
            { 0x80000000 | 9, 10 }, { QMetaType::QString, 25 }, { QMetaType::QString, 26 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'exercises'
        QtMocHelpers::PropertyData<QJsonArray>(15, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<ExerciseCatalogController, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Minuet::ExerciseCatalogController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Minuet25ExerciseCatalogControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Minuet25ExerciseCatalogControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Minuet25ExerciseCatalogControllerE_t>.metaTypes,
    nullptr
} };

void Minuet::ExerciseCatalogController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ExerciseCatalogController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->iconNameForExercise((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->actionIconNameForExercise((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 2: { QVariantList _r = _t->collectExercises((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->exerciseDescription((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->normalizedText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->actionMatches((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->exerciseMatchesSearch((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { QString _r = _t->practiceModeForExercise((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: { QVariantMap _r = _t->exerciseForInputMode((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QJsonArray*>(_v) = _t->exercises(); break;
        default: break;
        }
    }
}

const QMetaObject *Minuet::ExerciseCatalogController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Minuet::ExerciseCatalogController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Minuet25ExerciseCatalogControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Minuet::ExerciseCatalogController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
