/****************************************************************************
** Meta object code from reading C++ file 'settingscontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../minuet-26.08.0/src/app/settingscontroller.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'settingscontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Minuet18SettingsControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto Minuet::SettingsController::qt_create_metaobjectdata<qt_meta_tag_ZN6Minuet18SettingsControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Minuet::SettingsController",
        "rhythmPatternCountChanged",
        "",
        "rhythmPatternCount",
        "testExerciseCountChanged",
        "testExerciseCount",
        "volumeChanged",
        "volume",
        "pitchChanged",
        "pitch",
        "tempoChanged",
        "tempo",
        "exerciseSpeedChanged",
        "exerciseSpeed",
        "rhythmTempoChanged",
        "instrumentGroupChanged",
        "instrumentGroup",
        "instrumentChanged",
        "instrument",
        "rhythmInstrumentChanged",
        "rhythmInstrument",
        "microphoneInputDeviceIdChanged",
        "deviceId",
        "clappingCorrectnessTolerancePercentChanged",
        "tolerance",
        "singingPitchToleranceCentsChanged",
        "cents",
        "singingDisregardOctaveDifferenceChanged",
        "disregard",
        "singingScoringModeChanged",
        "mode",
        "singingVoiceClassChanged",
        "voiceClass",
        "singingPitchMethodChanged",
        "method",
        "singingMinimumPitchConfidenceChanged",
        "confidence",
        "singingInputGateLevelChanged",
        "inputGateLevel",
        "singingRequiredStablePitchFramesChanged",
        "frames",
        "clappingPitchMethodChanged",
        "clappingOnsetMethodChanged",
        "clappingMinimumPitchConfidenceChanged",
        "clappingOnsetThresholdChanged",
        "threshold",
        "clappingInputGateLevelChanged",
        "clappingMinimumOnsetStrengthChanged",
        "strength",
        "clappingRequiredStablePitchFramesChanged",
        "melodicOnboardingPromptShownChanged",
        "shown",
        "rhythmicOnboardingPromptShownChanged",
        "clappingOnboardingPromptShownChanged",
        "singingOnboardingPromptShownChanged",
        "setRhythmPatternCount",
        "setTestExerciseCount",
        "setVolume",
        "setPitch",
        "setTempo",
        "setExerciseSpeed",
        "setRhythmTempo",
        "setInstrumentGroup",
        "setInstrument",
        "setRhythmInstrument",
        "setMicrophoneInputDeviceId",
        "setClappingCorrectnessTolerancePercent",
        "setSingingPitchToleranceCents",
        "setSingingDisregardOctaveDifference",
        "setSingingScoringMode",
        "setSingingVoiceClass",
        "setSingingPitchMethod",
        "setSingingMinimumPitchConfidence",
        "setSingingInputGateLevel",
        "setSingingRequiredStablePitchFrames",
        "setClappingPitchMethod",
        "setClappingOnsetMethod",
        "setClappingMinimumPitchConfidence",
        "setClappingOnsetThreshold",
        "setClappingInputGateLevel",
        "setClappingMinimumOnsetStrength",
        "setClappingRequiredStablePitchFrames",
        "setMelodicOnboardingPromptShown",
        "setRhythmicOnboardingPromptShown",
        "setClappingOnboardingPromptShown",
        "setSingingOnboardingPromptShown",
        "resetAdvancedSettingsToDefaults",
        "takeOnboardingPrompt",
        "inputMode",
        "rhythmic",
        "rhythmTempo",
        "microphoneInputDeviceId",
        "clappingCorrectnessTolerancePercent",
        "singingPitchToleranceCents",
        "singingDisregardOctaveDifference",
        "singingScoringMode",
        "singingVoiceClass",
        "singingPitchMethod",
        "singingMinimumPitchConfidence",
        "singingInputGateLevel",
        "singingRequiredStablePitchFrames",
        "clappingPitchMethod",
        "clappingOnsetMethod",
        "clappingMinimumPitchConfidence",
        "clappingOnsetThreshold",
        "clappingInputGateLevel",
        "clappingMinimumOnsetStrength",
        "clappingRequiredStablePitchFrames",
        "melodicOnboardingPromptShown",
        "rhythmicOnboardingPromptShown",
        "clappingOnboardingPromptShown",
        "singingOnboardingPromptShown"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'rhythmPatternCountChanged'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'testExerciseCountChanged'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'volumeChanged'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'pitchChanged'
        QtMocHelpers::SignalData<void(int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Signal 'tempoChanged'
        QtMocHelpers::SignalData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Signal 'exerciseSpeedChanged'
        QtMocHelpers::SignalData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Signal 'rhythmTempoChanged'
        QtMocHelpers::SignalData<void(int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Signal 'instrumentGroupChanged'
        QtMocHelpers::SignalData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Signal 'instrumentChanged'
        QtMocHelpers::SignalData<void(int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Signal 'rhythmInstrumentChanged'
        QtMocHelpers::SignalData<void(int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Signal 'microphoneInputDeviceIdChanged'
        QtMocHelpers::SignalData<void(const QString &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Signal 'clappingCorrectnessTolerancePercentChanged'
        QtMocHelpers::SignalData<void(int)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 24 },
        }}),
        // Signal 'singingPitchToleranceCentsChanged'
        QtMocHelpers::SignalData<void(int)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Signal 'singingDisregardOctaveDifferenceChanged'
        QtMocHelpers::SignalData<void(bool)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 28 },
        }}),
        // Signal 'singingScoringModeChanged'
        QtMocHelpers::SignalData<void(int)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 30 },
        }}),
        // Signal 'singingVoiceClassChanged'
        QtMocHelpers::SignalData<void(int)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 32 },
        }}),
        // Signal 'singingPitchMethodChanged'
        QtMocHelpers::SignalData<void(int)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Signal 'singingMinimumPitchConfidenceChanged'
        QtMocHelpers::SignalData<void(double)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 36 },
        }}),
        // Signal 'singingInputGateLevelChanged'
        QtMocHelpers::SignalData<void(double)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 38 },
        }}),
        // Signal 'singingRequiredStablePitchFramesChanged'
        QtMocHelpers::SignalData<void(int)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 40 },
        }}),
        // Signal 'clappingPitchMethodChanged'
        QtMocHelpers::SignalData<void(int)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Signal 'clappingOnsetMethodChanged'
        QtMocHelpers::SignalData<void(int)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Signal 'clappingMinimumPitchConfidenceChanged'
        QtMocHelpers::SignalData<void(double)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 36 },
        }}),
        // Signal 'clappingOnsetThresholdChanged'
        QtMocHelpers::SignalData<void(double)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 45 },
        }}),
        // Signal 'clappingInputGateLevelChanged'
        QtMocHelpers::SignalData<void(double)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 38 },
        }}),
        // Signal 'clappingMinimumOnsetStrengthChanged'
        QtMocHelpers::SignalData<void(double)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 48 },
        }}),
        // Signal 'clappingRequiredStablePitchFramesChanged'
        QtMocHelpers::SignalData<void(int)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 40 },
        }}),
        // Signal 'melodicOnboardingPromptShownChanged'
        QtMocHelpers::SignalData<void(bool)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 51 },
        }}),
        // Signal 'rhythmicOnboardingPromptShownChanged'
        QtMocHelpers::SignalData<void(bool)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 51 },
        }}),
        // Signal 'clappingOnboardingPromptShownChanged'
        QtMocHelpers::SignalData<void(bool)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 51 },
        }}),
        // Signal 'singingOnboardingPromptShownChanged'
        QtMocHelpers::SignalData<void(bool)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 51 },
        }}),
        // Slot 'setRhythmPatternCount'
        QtMocHelpers::SlotData<void(int)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'setTestExerciseCount'
        QtMocHelpers::SlotData<void(int)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'setVolume'
        QtMocHelpers::SlotData<void(int)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'setPitch'
        QtMocHelpers::SlotData<void(int)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Slot 'setTempo'
        QtMocHelpers::SlotData<void(int)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Slot 'setExerciseSpeed'
        QtMocHelpers::SlotData<void(int)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Slot 'setRhythmTempo'
        QtMocHelpers::SlotData<void(int)>(61, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Slot 'setInstrumentGroup'
        QtMocHelpers::SlotData<void(int)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'setInstrument'
        QtMocHelpers::SlotData<void(int)>(63, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Slot 'setRhythmInstrument'
        QtMocHelpers::SlotData<void(int)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Slot 'setMicrophoneInputDeviceId'
        QtMocHelpers::SlotData<void(const QString &)>(65, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'setClappingCorrectnessTolerancePercent'
        QtMocHelpers::SlotData<void(int)>(66, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 24 },
        }}),
        // Slot 'setSingingPitchToleranceCents'
        QtMocHelpers::SlotData<void(int)>(67, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'setSingingDisregardOctaveDifference'
        QtMocHelpers::SlotData<void(bool)>(68, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 28 },
        }}),
        // Slot 'setSingingScoringMode'
        QtMocHelpers::SlotData<void(int)>(69, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 30 },
        }}),
        // Slot 'setSingingVoiceClass'
        QtMocHelpers::SlotData<void(int)>(70, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 32 },
        }}),
        // Slot 'setSingingPitchMethod'
        QtMocHelpers::SlotData<void(int)>(71, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Slot 'setSingingMinimumPitchConfidence'
        QtMocHelpers::SlotData<void(double)>(72, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 36 },
        }}),
        // Slot 'setSingingInputGateLevel'
        QtMocHelpers::SlotData<void(double)>(73, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 38 },
        }}),
        // Slot 'setSingingRequiredStablePitchFrames'
        QtMocHelpers::SlotData<void(int)>(74, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 40 },
        }}),
        // Slot 'setClappingPitchMethod'
        QtMocHelpers::SlotData<void(int)>(75, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Slot 'setClappingOnsetMethod'
        QtMocHelpers::SlotData<void(int)>(76, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Slot 'setClappingMinimumPitchConfidence'
        QtMocHelpers::SlotData<void(double)>(77, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 36 },
        }}),
        // Slot 'setClappingOnsetThreshold'
        QtMocHelpers::SlotData<void(double)>(78, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 45 },
        }}),
        // Slot 'setClappingInputGateLevel'
        QtMocHelpers::SlotData<void(double)>(79, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 38 },
        }}),
        // Slot 'setClappingMinimumOnsetStrength'
        QtMocHelpers::SlotData<void(double)>(80, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 48 },
        }}),
        // Slot 'setClappingRequiredStablePitchFrames'
        QtMocHelpers::SlotData<void(int)>(81, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 40 },
        }}),
        // Slot 'setMelodicOnboardingPromptShown'
        QtMocHelpers::SlotData<void(bool)>(82, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 51 },
        }}),
        // Slot 'setRhythmicOnboardingPromptShown'
        QtMocHelpers::SlotData<void(bool)>(83, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 51 },
        }}),
        // Slot 'setClappingOnboardingPromptShown'
        QtMocHelpers::SlotData<void(bool)>(84, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 51 },
        }}),
        // Slot 'setSingingOnboardingPromptShown'
        QtMocHelpers::SlotData<void(bool)>(85, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 51 },
        }}),
        // Method 'resetAdvancedSettingsToDefaults'
        QtMocHelpers::MethodData<void()>(86, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'takeOnboardingPrompt'
        QtMocHelpers::MethodData<bool(const QString &, bool)>(87, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 88 }, { QMetaType::Bool, 89 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'rhythmPatternCount'
        QtMocHelpers::PropertyData<int>(3, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'testExerciseCount'
        QtMocHelpers::PropertyData<int>(5, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'volume'
        QtMocHelpers::PropertyData<int>(7, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'pitch'
        QtMocHelpers::PropertyData<int>(9, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'tempo'
        QtMocHelpers::PropertyData<int>(11, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'exerciseSpeed'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'rhythmTempo'
        QtMocHelpers::PropertyData<int>(90, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'instrumentGroup'
        QtMocHelpers::PropertyData<int>(16, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'instrument'
        QtMocHelpers::PropertyData<int>(18, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'rhythmInstrument'
        QtMocHelpers::PropertyData<int>(20, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'microphoneInputDeviceId'
        QtMocHelpers::PropertyData<QString>(91, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'clappingCorrectnessTolerancePercent'
        QtMocHelpers::PropertyData<int>(92, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'singingPitchToleranceCents'
        QtMocHelpers::PropertyData<int>(93, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'singingDisregardOctaveDifference'
        QtMocHelpers::PropertyData<bool>(94, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'singingScoringMode'
        QtMocHelpers::PropertyData<int>(95, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'singingVoiceClass'
        QtMocHelpers::PropertyData<int>(96, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'singingPitchMethod'
        QtMocHelpers::PropertyData<int>(97, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'singingMinimumPitchConfidence'
        QtMocHelpers::PropertyData<double>(98, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'singingInputGateLevel'
        QtMocHelpers::PropertyData<double>(99, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'singingRequiredStablePitchFrames'
        QtMocHelpers::PropertyData<int>(100, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'clappingPitchMethod'
        QtMocHelpers::PropertyData<int>(101, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'clappingOnsetMethod'
        QtMocHelpers::PropertyData<int>(102, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 21),
        // property 'clappingMinimumPitchConfidence'
        QtMocHelpers::PropertyData<double>(103, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 22),
        // property 'clappingOnsetThreshold'
        QtMocHelpers::PropertyData<double>(104, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
        // property 'clappingInputGateLevel'
        QtMocHelpers::PropertyData<double>(105, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 24),
        // property 'clappingMinimumOnsetStrength'
        QtMocHelpers::PropertyData<double>(106, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 25),
        // property 'clappingRequiredStablePitchFrames'
        QtMocHelpers::PropertyData<int>(107, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 26),
        // property 'melodicOnboardingPromptShown'
        QtMocHelpers::PropertyData<bool>(108, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 27),
        // property 'rhythmicOnboardingPromptShown'
        QtMocHelpers::PropertyData<bool>(109, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 28),
        // property 'clappingOnboardingPromptShown'
        QtMocHelpers::PropertyData<bool>(110, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 29),
        // property 'singingOnboardingPromptShown'
        QtMocHelpers::PropertyData<bool>(111, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 30),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SettingsController, qt_meta_tag_ZN6Minuet18SettingsControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Minuet::SettingsController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Minuet18SettingsControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Minuet18SettingsControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Minuet18SettingsControllerE_t>.metaTypes,
    nullptr
} };

void Minuet::SettingsController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SettingsController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->rhythmPatternCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->testExerciseCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->volumeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->pitchChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->tempoChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->exerciseSpeedChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->rhythmTempoChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->instrumentGroupChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->instrumentChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->rhythmInstrumentChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->microphoneInputDeviceIdChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->clappingCorrectnessTolerancePercentChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->singingPitchToleranceCentsChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->singingDisregardOctaveDifferenceChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->singingScoringModeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->singingVoiceClassChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->singingPitchMethodChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->singingMinimumPitchConfidenceChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 18: _t->singingInputGateLevelChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 19: _t->singingRequiredStablePitchFramesChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->clappingPitchMethodChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 21: _t->clappingOnsetMethodChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: _t->clappingMinimumPitchConfidenceChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 23: _t->clappingOnsetThresholdChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 24: _t->clappingInputGateLevelChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 25: _t->clappingMinimumOnsetStrengthChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 26: _t->clappingRequiredStablePitchFramesChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 27: _t->melodicOnboardingPromptShownChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 28: _t->rhythmicOnboardingPromptShownChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 29: _t->clappingOnboardingPromptShownChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 30: _t->singingOnboardingPromptShownChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 31: _t->setRhythmPatternCount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 32: _t->setTestExerciseCount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 33: _t->setVolume((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 34: _t->setPitch((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 35: _t->setTempo((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 36: _t->setExerciseSpeed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 37: _t->setRhythmTempo((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 38: _t->setInstrumentGroup((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 39: _t->setInstrument((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 40: _t->setRhythmInstrument((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 41: _t->setMicrophoneInputDeviceId((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 42: _t->setClappingCorrectnessTolerancePercent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 43: _t->setSingingPitchToleranceCents((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 44: _t->setSingingDisregardOctaveDifference((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 45: _t->setSingingScoringMode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 46: _t->setSingingVoiceClass((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 47: _t->setSingingPitchMethod((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 48: _t->setSingingMinimumPitchConfidence((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 49: _t->setSingingInputGateLevel((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 50: _t->setSingingRequiredStablePitchFrames((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 51: _t->setClappingPitchMethod((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 52: _t->setClappingOnsetMethod((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 53: _t->setClappingMinimumPitchConfidence((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 54: _t->setClappingOnsetThreshold((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 55: _t->setClappingInputGateLevel((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 56: _t->setClappingMinimumOnsetStrength((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 57: _t->setClappingRequiredStablePitchFrames((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 58: _t->setMelodicOnboardingPromptShown((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 59: _t->setRhythmicOnboardingPromptShown((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 60: _t->setClappingOnboardingPromptShown((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 61: _t->setSingingOnboardingPromptShown((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 62: _t->resetAdvancedSettingsToDefaults(); break;
        case 63: { bool _r = _t->takeOnboardingPrompt((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(int )>(_a, &SettingsController::rhythmPatternCountChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(int )>(_a, &SettingsController::testExerciseCountChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(int )>(_a, &SettingsController::volumeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(int )>(_a, &SettingsController::pitchChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(int )>(_a, &SettingsController::tempoChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(int )>(_a, &SettingsController::exerciseSpeedChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(int )>(_a, &SettingsController::rhythmTempoChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(int )>(_a, &SettingsController::instrumentGroupChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(int )>(_a, &SettingsController::instrumentChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(int )>(_a, &SettingsController::rhythmInstrumentChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(const QString & )>(_a, &SettingsController::microphoneInputDeviceIdChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(int )>(_a, &SettingsController::clappingCorrectnessTolerancePercentChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(int )>(_a, &SettingsController::singingPitchToleranceCentsChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(bool )>(_a, &SettingsController::singingDisregardOctaveDifferenceChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(int )>(_a, &SettingsController::singingScoringModeChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(int )>(_a, &SettingsController::singingVoiceClassChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(int )>(_a, &SettingsController::singingPitchMethodChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(double )>(_a, &SettingsController::singingMinimumPitchConfidenceChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(double )>(_a, &SettingsController::singingInputGateLevelChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(int )>(_a, &SettingsController::singingRequiredStablePitchFramesChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(int )>(_a, &SettingsController::clappingPitchMethodChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(int )>(_a, &SettingsController::clappingOnsetMethodChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(double )>(_a, &SettingsController::clappingMinimumPitchConfidenceChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(double )>(_a, &SettingsController::clappingOnsetThresholdChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(double )>(_a, &SettingsController::clappingInputGateLevelChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(double )>(_a, &SettingsController::clappingMinimumOnsetStrengthChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(int )>(_a, &SettingsController::clappingRequiredStablePitchFramesChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(bool )>(_a, &SettingsController::melodicOnboardingPromptShownChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(bool )>(_a, &SettingsController::rhythmicOnboardingPromptShownChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(bool )>(_a, &SettingsController::clappingOnboardingPromptShownChanged, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (SettingsController::*)(bool )>(_a, &SettingsController::singingOnboardingPromptShownChanged, 30))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->rhythmPatternCount(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->testExerciseCount(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->volume(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->pitch(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->tempo(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->exerciseSpeed(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->rhythmTempo(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->instrumentGroup(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->instrument(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->rhythmInstrument(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->microphoneInputDeviceId(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->clappingCorrectnessTolerancePercent(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->singingPitchToleranceCents(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->singingDisregardOctaveDifference(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->singingScoringMode(); break;
        case 15: *reinterpret_cast<int*>(_v) = _t->singingVoiceClass(); break;
        case 16: *reinterpret_cast<int*>(_v) = _t->singingPitchMethod(); break;
        case 17: *reinterpret_cast<double*>(_v) = _t->singingMinimumPitchConfidence(); break;
        case 18: *reinterpret_cast<double*>(_v) = _t->singingInputGateLevel(); break;
        case 19: *reinterpret_cast<int*>(_v) = _t->singingRequiredStablePitchFrames(); break;
        case 20: *reinterpret_cast<int*>(_v) = _t->clappingPitchMethod(); break;
        case 21: *reinterpret_cast<int*>(_v) = _t->clappingOnsetMethod(); break;
        case 22: *reinterpret_cast<double*>(_v) = _t->clappingMinimumPitchConfidence(); break;
        case 23: *reinterpret_cast<double*>(_v) = _t->clappingOnsetThreshold(); break;
        case 24: *reinterpret_cast<double*>(_v) = _t->clappingInputGateLevel(); break;
        case 25: *reinterpret_cast<double*>(_v) = _t->clappingMinimumOnsetStrength(); break;
        case 26: *reinterpret_cast<int*>(_v) = _t->clappingRequiredStablePitchFrames(); break;
        case 27: *reinterpret_cast<bool*>(_v) = _t->melodicOnboardingPromptShown(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->rhythmicOnboardingPromptShown(); break;
        case 29: *reinterpret_cast<bool*>(_v) = _t->clappingOnboardingPromptShown(); break;
        case 30: *reinterpret_cast<bool*>(_v) = _t->singingOnboardingPromptShown(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setRhythmPatternCount(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setTestExerciseCount(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setVolume(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setPitch(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setTempo(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setExerciseSpeed(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setRhythmTempo(*reinterpret_cast<int*>(_v)); break;
        case 7: _t->setInstrumentGroup(*reinterpret_cast<int*>(_v)); break;
        case 8: _t->setInstrument(*reinterpret_cast<int*>(_v)); break;
        case 9: _t->setRhythmInstrument(*reinterpret_cast<int*>(_v)); break;
        case 10: _t->setMicrophoneInputDeviceId(*reinterpret_cast<QString*>(_v)); break;
        case 11: _t->setClappingCorrectnessTolerancePercent(*reinterpret_cast<int*>(_v)); break;
        case 12: _t->setSingingPitchToleranceCents(*reinterpret_cast<int*>(_v)); break;
        case 13: _t->setSingingDisregardOctaveDifference(*reinterpret_cast<bool*>(_v)); break;
        case 14: _t->setSingingScoringMode(*reinterpret_cast<int*>(_v)); break;
        case 15: _t->setSingingVoiceClass(*reinterpret_cast<int*>(_v)); break;
        case 16: _t->setSingingPitchMethod(*reinterpret_cast<int*>(_v)); break;
        case 17: _t->setSingingMinimumPitchConfidence(*reinterpret_cast<double*>(_v)); break;
        case 18: _t->setSingingInputGateLevel(*reinterpret_cast<double*>(_v)); break;
        case 19: _t->setSingingRequiredStablePitchFrames(*reinterpret_cast<int*>(_v)); break;
        case 20: _t->setClappingPitchMethod(*reinterpret_cast<int*>(_v)); break;
        case 21: _t->setClappingOnsetMethod(*reinterpret_cast<int*>(_v)); break;
        case 22: _t->setClappingMinimumPitchConfidence(*reinterpret_cast<double*>(_v)); break;
        case 23: _t->setClappingOnsetThreshold(*reinterpret_cast<double*>(_v)); break;
        case 24: _t->setClappingInputGateLevel(*reinterpret_cast<double*>(_v)); break;
        case 25: _t->setClappingMinimumOnsetStrength(*reinterpret_cast<double*>(_v)); break;
        case 26: _t->setClappingRequiredStablePitchFrames(*reinterpret_cast<int*>(_v)); break;
        case 27: _t->setMelodicOnboardingPromptShown(*reinterpret_cast<bool*>(_v)); break;
        case 28: _t->setRhythmicOnboardingPromptShown(*reinterpret_cast<bool*>(_v)); break;
        case 29: _t->setClappingOnboardingPromptShown(*reinterpret_cast<bool*>(_v)); break;
        case 30: _t->setSingingOnboardingPromptShown(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Minuet::SettingsController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Minuet::SettingsController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Minuet18SettingsControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Minuet::SettingsController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 64)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 64;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 64)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 64;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 31;
    }
    return _id;
}

// SIGNAL 0
void Minuet::SettingsController::rhythmPatternCountChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Minuet::SettingsController::testExerciseCountChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Minuet::SettingsController::volumeChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Minuet::SettingsController::pitchChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Minuet::SettingsController::tempoChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Minuet::SettingsController::exerciseSpeedChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Minuet::SettingsController::rhythmTempoChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Minuet::SettingsController::instrumentGroupChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Minuet::SettingsController::instrumentChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Minuet::SettingsController::rhythmInstrumentChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Minuet::SettingsController::microphoneInputDeviceIdChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void Minuet::SettingsController::clappingCorrectnessTolerancePercentChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void Minuet::SettingsController::singingPitchToleranceCentsChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void Minuet::SettingsController::singingDisregardOctaveDifferenceChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void Minuet::SettingsController::singingScoringModeChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void Minuet::SettingsController::singingVoiceClassChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void Minuet::SettingsController::singingPitchMethodChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void Minuet::SettingsController::singingMinimumPitchConfidenceChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void Minuet::SettingsController::singingInputGateLevelChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void Minuet::SettingsController::singingRequiredStablePitchFramesChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void Minuet::SettingsController::clappingPitchMethodChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void Minuet::SettingsController::clappingOnsetMethodChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void Minuet::SettingsController::clappingMinimumPitchConfidenceChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void Minuet::SettingsController::clappingOnsetThresholdChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void Minuet::SettingsController::clappingInputGateLevelChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1);
}

// SIGNAL 25
void Minuet::SettingsController::clappingMinimumOnsetStrengthChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1);
}

// SIGNAL 26
void Minuet::SettingsController::clappingRequiredStablePitchFramesChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1);
}

// SIGNAL 27
void Minuet::SettingsController::melodicOnboardingPromptShownChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 27, nullptr, _t1);
}

// SIGNAL 28
void Minuet::SettingsController::rhythmicOnboardingPromptShownChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 28, nullptr, _t1);
}

// SIGNAL 29
void Minuet::SettingsController::clappingOnboardingPromptShownChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 29, nullptr, _t1);
}

// SIGNAL 30
void Minuet::SettingsController::singingOnboardingPromptShownChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 30, nullptr, _t1);
}
QT_WARNING_POP
