// SPDX-FileCopyrightText: 2026 Sandro Andrade <sandroandrade@kde.org>
//
// SPDX-License-Identifier: GPL-2.0-or-later

#include "imicrophoneinputcontroller.h"

namespace Minuet
{
IMicrophoneInputController::IMicrophoneInputController(QObject *parent)
    : IPlugin(parent)
{
}
}
