/****************************************************************************
** Meta object code from reading C++ file 'isoundcontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../minuet-26.08.0/src/interfaces/isoundcontroller.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'isoundcontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Minuet16ISoundControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto Minuet::ISoundController::qt_create_metaobjectdata<qt_meta_tag_ZN6Minuet16ISoundControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Minuet::ISoundController",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "ISoundController is provided by Core",
        "playModeChanged",
        "",
        "newPlayMode",
        "pitchChanged",
        "newPitch",
        "volumeChanged",
        "newVolume",
        "tempoChanged",
        "newTempo",
        "rhythmCountInBeatsChanged",
        "beats",
        "rhythmCountInSubdivisionsChanged",
        "subdivisions",
        "instrumentChanged",
        "newInstrument",
        "rhythmInstrumentChanged",
        "newRhythmInstrument",
        "stateChanged",
        "Minuet::ISoundController::State",
        "newState",
        "playbackLabelChanged",
        "newPlaybackLabel",
        "instrumentGroupsChanged",
        "instrumentsChanged",
        "rhythmInstrumentsChanged",
        "countInChanged",
        "count",
        "countInSubTick",
        "setPitch",
        "pitch",
        "setVolume",
        "volume",
        "setTempo",
        "tempo",
        "setRhythmCountInBeats",
        "setRhythmCountInSubdivisions",
        "setInstrument",
        "instrument",
        "setRhythmInstrument",
        "rhythmInstrument",
        "prepareFromExerciseOptions",
        "QJsonArray",
        "selectedExerciseOptions",
        "prepareFromMidiFile",
        "fileName",
        "playCountIn",
        "playSilentCountIn",
        "play",
        "pause",
        "stop",
        "reset",
        "playMode",
        "rhythmCountInBeats",
        "rhythmCountInSubdivisions",
        "state",
        "State",
        "playbackLabel",
        "instrumentGroups",
        "QVariantList",
        "instruments",
        "rhythmInstruments",
        "StoppedState",
        "PlayingState",
        "PausedState"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'playModeChanged'
        QtMocHelpers::SignalData<void(QString)>(7, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'pitchChanged'
        QtMocHelpers::SignalData<void(qint8)>(10, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::SChar, 11 },
        }}),
        // Signal 'volumeChanged'
        QtMocHelpers::SignalData<void(quint8)>(12, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UChar, 13 },
        }}),
        // Signal 'tempoChanged'
        QtMocHelpers::SignalData<void(quint8)>(14, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UChar, 15 },
        }}),
        // Signal 'rhythmCountInBeatsChanged'
        QtMocHelpers::SignalData<void(int)>(16, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Signal 'rhythmCountInSubdivisionsChanged'
        QtMocHelpers::SignalData<void(int)>(18, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Signal 'instrumentChanged'
        QtMocHelpers::SignalData<void(int)>(20, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
        // Signal 'rhythmInstrumentChanged'
        QtMocHelpers::SignalData<void(int)>(22, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void(Minuet::ISoundController::State)>(24, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Signal 'playbackLabelChanged'
        QtMocHelpers::SignalData<void(QString)>(27, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Signal 'instrumentGroupsChanged'
        QtMocHelpers::SignalData<void()>(29, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'instrumentsChanged'
        QtMocHelpers::SignalData<void()>(30, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rhythmInstrumentsChanged'
        QtMocHelpers::SignalData<void()>(31, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'countInChanged'
        QtMocHelpers::SignalData<void(int)>(32, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 33 },
        }}),
        // Signal 'countInSubTick'
        QtMocHelpers::SignalData<void()>(34, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setPitch'
        QtMocHelpers::SlotData<void(qint8)>(35, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::SChar, 36 },
        }}),
        // Slot 'setVolume'
        QtMocHelpers::SlotData<void(quint8)>(37, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UChar, 38 },
        }}),
        // Slot 'setTempo'
        QtMocHelpers::SlotData<void(quint8)>(39, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UChar, 40 },
        }}),
        // Slot 'setRhythmCountInBeats'
        QtMocHelpers::SlotData<void(int)>(41, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Slot 'setRhythmCountInSubdivisions'
        QtMocHelpers::SlotData<void(int)>(42, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Slot 'setInstrument'
        QtMocHelpers::SlotData<void(int)>(43, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 44 },
        }}),
        // Slot 'setRhythmInstrument'
        QtMocHelpers::SlotData<void(int)>(45, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 46 },
        }}),
        // Slot 'prepareFromExerciseOptions'
        QtMocHelpers::SlotData<void(QJsonArray)>(47, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 48, 49 },
        }}),
        // Slot 'prepareFromMidiFile'
        QtMocHelpers::SlotData<void(const QString &)>(50, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 51 },
        }}),
        // Slot 'playCountIn'
        QtMocHelpers::SlotData<void(int)>(52, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Slot 'playSilentCountIn'
        QtMocHelpers::SlotData<void(int)>(53, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Slot 'play'
        QtMocHelpers::SlotData<void()>(54, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pause'
        QtMocHelpers::SlotData<void()>(55, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(56, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reset'
        QtMocHelpers::SlotData<void()>(57, 8, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'playMode'
        QtMocHelpers::PropertyData<QString>(58, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'pitch'
        QtMocHelpers::PropertyData<qint8>(36, QMetaType::SChar, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'volume'
        QtMocHelpers::PropertyData<quint8>(38, QMetaType::UChar, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'tempo'
        QtMocHelpers::PropertyData<quint8>(40, QMetaType::UChar, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'rhythmCountInBeats'
        QtMocHelpers::PropertyData<int>(59, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'rhythmCountInSubdivisions'
        QtMocHelpers::PropertyData<int>(60, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'instrument'
        QtMocHelpers::PropertyData<int>(44, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'rhythmInstrument'
        QtMocHelpers::PropertyData<int>(46, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'state'
        QtMocHelpers::PropertyData<enum State>(61, 0x80000000 | 62, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 8),
        // property 'playbackLabel'
        QtMocHelpers::PropertyData<QString>(63, QMetaType::QString, QMC::DefaultPropertyFlags, 9),
        // property 'instrumentGroups'
        QtMocHelpers::PropertyData<QVariantList>(64, 0x80000000 | 65, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 10),
        // property 'instruments'
        QtMocHelpers::PropertyData<QVariantList>(66, 0x80000000 | 65, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 11),
        // property 'rhythmInstruments'
        QtMocHelpers::PropertyData<QVariantList>(67, 0x80000000 | 65, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 12),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'State'
        QtMocHelpers::EnumData<enum State>(62, 62, QMC::EnumIsScoped).add({
            {   68, State::StoppedState },
            {   69, State::PlayingState },
            {   70, State::PausedState },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<ISoundController, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Minuet::ISoundController::staticMetaObject = { {
    QMetaObject::SuperData::link<IPlugin::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Minuet16ISoundControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Minuet16ISoundControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Minuet16ISoundControllerE_t>.metaTypes,
    nullptr
} };

void Minuet::ISoundController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ISoundController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->playModeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->pitchChanged((*reinterpret_cast<std::add_pointer_t<qint8>>(_a[1]))); break;
        case 2: _t->volumeChanged((*reinterpret_cast<std::add_pointer_t<quint8>>(_a[1]))); break;
        case 3: _t->tempoChanged((*reinterpret_cast<std::add_pointer_t<quint8>>(_a[1]))); break;
        case 4: _t->rhythmCountInBeatsChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->rhythmCountInSubdivisionsChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->instrumentChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->rhythmInstrumentChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->stateChanged((*reinterpret_cast<std::add_pointer_t<Minuet::ISoundController::State>>(_a[1]))); break;
        case 9: _t->playbackLabelChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->instrumentGroupsChanged(); break;
        case 11: _t->instrumentsChanged(); break;
        case 12: _t->rhythmInstrumentsChanged(); break;
        case 13: _t->countInChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->countInSubTick(); break;
        case 15: _t->setPitch((*reinterpret_cast<std::add_pointer_t<qint8>>(_a[1]))); break;
        case 16: _t->setVolume((*reinterpret_cast<std::add_pointer_t<quint8>>(_a[1]))); break;
        case 17: _t->setTempo((*reinterpret_cast<std::add_pointer_t<quint8>>(_a[1]))); break;
        case 18: _t->setRhythmCountInBeats((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->setRhythmCountInSubdivisions((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->setInstrument((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 21: _t->setRhythmInstrument((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: _t->prepareFromExerciseOptions((*reinterpret_cast<std::add_pointer_t<QJsonArray>>(_a[1]))); break;
        case 23: _t->prepareFromMidiFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: _t->playCountIn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 25: _t->playSilentCountIn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 26: _t->play(); break;
        case 27: _t->pause(); break;
        case 28: _t->stop(); break;
        case 29: _t->reset(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ISoundController::*)(QString )>(_a, &ISoundController::playModeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ISoundController::*)(qint8 )>(_a, &ISoundController::pitchChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ISoundController::*)(quint8 )>(_a, &ISoundController::volumeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ISoundController::*)(quint8 )>(_a, &ISoundController::tempoChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ISoundController::*)(int )>(_a, &ISoundController::rhythmCountInBeatsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ISoundController::*)(int )>(_a, &ISoundController::rhythmCountInSubdivisionsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ISoundController::*)(int )>(_a, &ISoundController::instrumentChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ISoundController::*)(int )>(_a, &ISoundController::rhythmInstrumentChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ISoundController::*)(Minuet::ISoundController::State )>(_a, &ISoundController::stateChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ISoundController::*)(QString )>(_a, &ISoundController::playbackLabelChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ISoundController::*)()>(_a, &ISoundController::instrumentGroupsChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ISoundController::*)()>(_a, &ISoundController::instrumentsChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (ISoundController::*)()>(_a, &ISoundController::rhythmInstrumentsChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (ISoundController::*)(int )>(_a, &ISoundController::countInChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (ISoundController::*)()>(_a, &ISoundController::countInSubTick, 14))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->m_playMode; break;
        case 1: *reinterpret_cast<qint8*>(_v) = _t->m_pitch; break;
        case 2: *reinterpret_cast<quint8*>(_v) = _t->m_volume; break;
        case 3: *reinterpret_cast<quint8*>(_v) = _t->m_tempo; break;
        case 4: *reinterpret_cast<int*>(_v) = _t->rhythmCountInBeats(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->rhythmCountInSubdivisions(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->instrument(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->rhythmInstrument(); break;
        case 8: *reinterpret_cast<enum State*>(_v) = _t->state(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->playbackLabel(); break;
        case 10: *reinterpret_cast<QVariantList*>(_v) = _t->instrumentGroups(); break;
        case 11: *reinterpret_cast<QVariantList*>(_v) = _t->instruments(); break;
        case 12: *reinterpret_cast<QVariantList*>(_v) = _t->rhythmInstruments(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->m_playMode, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->playModeChanged(_t->m_playMode);
            break;
        case 1: _t->setPitch(*reinterpret_cast<qint8*>(_v)); break;
        case 2: _t->setVolume(*reinterpret_cast<quint8*>(_v)); break;
        case 3: _t->setTempo(*reinterpret_cast<quint8*>(_v)); break;
        case 4: _t->setRhythmCountInBeats(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setRhythmCountInSubdivisions(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setInstrument(*reinterpret_cast<int*>(_v)); break;
        case 7: _t->setRhythmInstrument(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Minuet::ISoundController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Minuet::ISoundController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Minuet16ISoundControllerE_t>.strings))
        return static_cast<void*>(this);
    return IPlugin::qt_metacast(_clname);
}

int Minuet::ISoundController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = IPlugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 30)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 30;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void Minuet::ISoundController::playModeChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Minuet::ISoundController::pitchChanged(qint8 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Minuet::ISoundController::volumeChanged(quint8 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Minuet::ISoundController::tempoChanged(quint8 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Minuet::ISoundController::rhythmCountInBeatsChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Minuet::ISoundController::rhythmCountInSubdivisionsChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Minuet::ISoundController::instrumentChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Minuet::ISoundController::rhythmInstrumentChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Minuet::ISoundController::stateChanged(Minuet::ISoundController::State _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Minuet::ISoundController::playbackLabelChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Minuet::ISoundController::instrumentGroupsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Minuet::ISoundController::instrumentsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Minuet::ISoundController::rhythmInstrumentsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void Minuet::ISoundController::countInChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void Minuet::ISoundController::countInSubTick()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}
QT_WARNING_POP
