/****************************************************************************
** Meta object code from reading C++ file 'imicrophoneinputcontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../minuet-26.08.0/src/interfaces/imicrophoneinputcontroller.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'imicrophoneinputcontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Minuet26IMicrophoneInputControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto Minuet::IMicrophoneInputController::qt_create_metaobjectdata<qt_meta_tag_ZN6Minuet26IMicrophoneInputControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Minuet::IMicrophoneInputController",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "IMicrophoneInputController is provided by Core",
        "runningChanged",
        "",
        "statusChanged",
        "captureTimeChanged",
        "analysisPendingChanged",
        "presetChanged",
        "analysisModeChanged",
        "voiceClassChanged",
        "pitchMethodChanged",
        "onsetMethodChanged",
        "minimumPitchConfidenceChanged",
        "pitchSilenceDbChanged",
        "onsetThresholdChanged",
        "inputGateLevelChanged",
        "noiseFloorLevelChanged",
        "noiseCalibrationActiveChanged",
        "minimumOnsetStrengthChanged",
        "requiredStablePitchFramesChanged",
        "inputDeviceDescriptionChanged",
        "inputDevicesChanged",
        "inputDeviceAvailableChanged",
        "inputDeviceIdChanged",
        "audioLevelChanged",
        "audioStatsChanged",
        "pitchChanged",
        "rhythmChanged",
        "pitchDetected",
        "seconds",
        "midiNote",
        "cents",
        "confidence",
        "onsetDetected",
        "strength",
        "inputAnalysisFinished",
        "inputAnalysisFailed",
        "message",
        "setPreset",
        "Preset",
        "preset",
        "setAnalysisMode",
        "AnalysisMode",
        "mode",
        "setVoiceClass",
        "VoiceClass",
        "voiceClass",
        "setPitchMethod",
        "PitchMethod",
        "pitchMethod",
        "setOnsetMethod",
        "OnsetMethod",
        "onsetMethod",
        "setMinimumPitchConfidence",
        "setPitchSilenceDb",
        "silenceDb",
        "setOnsetThreshold",
        "threshold",
        "setInputGateLevel",
        "inputGateLevel",
        "setMinimumOnsetStrength",
        "setRequiredStablePitchFrames",
        "frames",
        "setInputDeviceId",
        "deviceId",
        "start",
        "stop",
        "resetInputAnalysisState",
        "finalizeInputAnalysis",
        "calibrateNoiseFloor",
        "presetName",
        "voiceClassName",
        "pitchMethodName",
        "onsetMethodName",
        "running",
        "status",
        "analysisTimeSeconds",
        "captureTimeSeconds",
        "analysisPending",
        "analysisMode",
        "minimumPitchConfidence",
        "pitchSilenceDb",
        "onsetThreshold",
        "noiseFloorLevel",
        "inputGateOpen",
        "noiseCalibrationActive",
        "minimumOnsetStrength",
        "requiredStablePitchFrames",
        "stablePitchFrameCount",
        "inputDeviceDescription",
        "inputDevices",
        "QVariantList",
        "inputDeviceAvailable",
        "inputDeviceId",
        "audioLevel",
        "peakLevel",
        "bytesRead",
        "processedSamples",
        "frequencyHz",
        "noteName",
        "pitchConfidence",
        "voiced",
        "onsetCount",
        "lastOnsetSeconds",
        "Singing",
        "Clapping",
        "SingingPitchOnly",
        "ClappingOnsetOnly",
        "Soprano",
        "Alto",
        "Tenor",
        "Bass",
        "YinFft",
        "Yin",
        "YinFast",
        "MComb",
        "Schmitt",
        "SpecAcf",
        "FComb",
        "Complex",
        "Hfc",
        "Energy",
        "SpecFlux",
        "Phase",
        "SpecDiff",
        "Kl",
        "Mkl"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'runningChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'captureTimeChanged'
        QtMocHelpers::SignalData<void()>(10, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'analysisPendingChanged'
        QtMocHelpers::SignalData<void()>(11, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'presetChanged'
        QtMocHelpers::SignalData<void()>(12, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'analysisModeChanged'
        QtMocHelpers::SignalData<void()>(13, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'voiceClassChanged'
        QtMocHelpers::SignalData<void()>(14, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pitchMethodChanged'
        QtMocHelpers::SignalData<void()>(15, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'onsetMethodChanged'
        QtMocHelpers::SignalData<void()>(16, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minimumPitchConfidenceChanged'
        QtMocHelpers::SignalData<void()>(17, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pitchSilenceDbChanged'
        QtMocHelpers::SignalData<void()>(18, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'onsetThresholdChanged'
        QtMocHelpers::SignalData<void()>(19, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputGateLevelChanged'
        QtMocHelpers::SignalData<void()>(20, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'noiseFloorLevelChanged'
        QtMocHelpers::SignalData<void()>(21, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'noiseCalibrationActiveChanged'
        QtMocHelpers::SignalData<void()>(22, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minimumOnsetStrengthChanged'
        QtMocHelpers::SignalData<void()>(23, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requiredStablePitchFramesChanged'
        QtMocHelpers::SignalData<void()>(24, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputDeviceDescriptionChanged'
        QtMocHelpers::SignalData<void()>(25, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputDevicesChanged'
        QtMocHelpers::SignalData<void()>(26, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputDeviceAvailableChanged'
        QtMocHelpers::SignalData<void()>(27, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputDeviceIdChanged'
        QtMocHelpers::SignalData<void()>(28, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audioLevelChanged'
        QtMocHelpers::SignalData<void()>(29, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audioStatsChanged'
        QtMocHelpers::SignalData<void()>(30, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pitchChanged'
        QtMocHelpers::SignalData<void()>(31, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rhythmChanged'
        QtMocHelpers::SignalData<void()>(32, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pitchDetected'
        QtMocHelpers::SignalData<void(double, int, double, double)>(33, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 34 }, { QMetaType::Int, 35 }, { QMetaType::Double, 36 }, { QMetaType::Double, 37 },
        }}),
        // Signal 'onsetDetected'
        QtMocHelpers::SignalData<void(double, double)>(38, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 34 }, { QMetaType::Double, 39 },
        }}),
        // Signal 'inputAnalysisFinished'
        QtMocHelpers::SignalData<void()>(40, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputAnalysisFailed'
        QtMocHelpers::SignalData<void(const QString &)>(41, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 42 },
        }}),
        // Slot 'setPreset'
        QtMocHelpers::SlotData<void(enum Preset)>(43, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 44, 45 },
        }}),
        // Slot 'setAnalysisMode'
        QtMocHelpers::SlotData<void(enum AnalysisMode)>(46, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 47, 48 },
        }}),
        // Slot 'setVoiceClass'
        QtMocHelpers::SlotData<void(enum VoiceClass)>(49, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 50, 51 },
        }}),
        // Slot 'setPitchMethod'
        QtMocHelpers::SlotData<void(enum PitchMethod)>(52, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'setOnsetMethod'
        QtMocHelpers::SlotData<void(enum OnsetMethod)>(55, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 56, 57 },
        }}),
        // Slot 'setMinimumPitchConfidence'
        QtMocHelpers::SlotData<void(double)>(58, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 37 },
        }}),
        // Slot 'setPitchSilenceDb'
        QtMocHelpers::SlotData<void(double)>(59, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 60 },
        }}),
        // Slot 'setOnsetThreshold'
        QtMocHelpers::SlotData<void(double)>(61, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 62 },
        }}),
        // Slot 'setInputGateLevel'
        QtMocHelpers::SlotData<void(double)>(63, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 64 },
        }}),
        // Slot 'setMinimumOnsetStrength'
        QtMocHelpers::SlotData<void(double)>(65, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 39 },
        }}),
        // Slot 'setRequiredStablePitchFrames'
        QtMocHelpers::SlotData<void(int)>(66, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 67 },
        }}),
        // Slot 'setInputDeviceId'
        QtMocHelpers::SlotData<void(const QString &)>(68, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 69 },
        }}),
        // Slot 'start'
        QtMocHelpers::SlotData<void()>(70, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(71, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resetInputAnalysisState'
        QtMocHelpers::SlotData<void()>(72, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'finalizeInputAnalysis'
        QtMocHelpers::SlotData<void()>(73, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'calibrateNoiseFloor'
        QtMocHelpers::SlotData<void()>(74, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'presetName'
        QtMocHelpers::SlotData<QString(int) const>(75, 8, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 45 },
        }}),
        // Slot 'voiceClassName'
        QtMocHelpers::SlotData<QString(int) const>(76, 8, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 51 },
        }}),
        // Slot 'pitchMethodName'
        QtMocHelpers::SlotData<QString(int) const>(77, 8, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 54 },
        }}),
        // Slot 'onsetMethodName'
        QtMocHelpers::SlotData<QString(int) const>(78, 8, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 57 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'running'
        QtMocHelpers::PropertyData<bool>(79, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'status'
        QtMocHelpers::PropertyData<QString>(80, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'analysisTimeSeconds'
        QtMocHelpers::PropertyData<double>(81, QMetaType::Double, QMC::DefaultPropertyFlags, 22),
        // property 'captureTimeSeconds'
        QtMocHelpers::PropertyData<double>(82, QMetaType::Double, QMC::DefaultPropertyFlags, 2),
        // property 'analysisPending'
        QtMocHelpers::PropertyData<bool>(83, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'preset'
        QtMocHelpers::PropertyData<enum Preset>(45, 0x80000000 | 44, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'analysisMode'
        QtMocHelpers::PropertyData<enum AnalysisMode>(84, 0x80000000 | 47, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'voiceClass'
        QtMocHelpers::PropertyData<enum VoiceClass>(51, 0x80000000 | 50, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'pitchMethod'
        QtMocHelpers::PropertyData<enum PitchMethod>(54, 0x80000000 | 53, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'onsetMethod'
        QtMocHelpers::PropertyData<enum OnsetMethod>(57, 0x80000000 | 56, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 8),
        // property 'minimumPitchConfidence'
        QtMocHelpers::PropertyData<double>(85, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'pitchSilenceDb'
        QtMocHelpers::PropertyData<double>(86, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'onsetThreshold'
        QtMocHelpers::PropertyData<double>(87, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'inputGateLevel'
        QtMocHelpers::PropertyData<double>(64, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'noiseFloorLevel'
        QtMocHelpers::PropertyData<double>(88, QMetaType::Double, QMC::DefaultPropertyFlags, 13),
        // property 'inputGateOpen'
        QtMocHelpers::PropertyData<bool>(89, QMetaType::Bool, QMC::DefaultPropertyFlags, 21),
        // property 'noiseCalibrationActive'
        QtMocHelpers::PropertyData<bool>(90, QMetaType::Bool, QMC::DefaultPropertyFlags, 14),
        // property 'minimumOnsetStrength'
        QtMocHelpers::PropertyData<double>(91, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'requiredStablePitchFrames'
        QtMocHelpers::PropertyData<int>(92, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'stablePitchFrameCount'
        QtMocHelpers::PropertyData<int>(93, QMetaType::Int, QMC::DefaultPropertyFlags, 23),
        // property 'inputDeviceDescription'
        QtMocHelpers::PropertyData<QString>(94, QMetaType::QString, QMC::DefaultPropertyFlags, 17),
        // property 'inputDevices'
        QtMocHelpers::PropertyData<QVariantList>(95, 0x80000000 | 96, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 18),
        // property 'inputDeviceAvailable'
        QtMocHelpers::PropertyData<bool>(97, QMetaType::Bool, QMC::DefaultPropertyFlags, 19),
        // property 'inputDeviceId'
        QtMocHelpers::PropertyData<QString>(98, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'audioLevel'
        QtMocHelpers::PropertyData<double>(99, QMetaType::Double, QMC::DefaultPropertyFlags, 21),
        // property 'peakLevel'
        QtMocHelpers::PropertyData<double>(100, QMetaType::Double, QMC::DefaultPropertyFlags, 21),
        // property 'bytesRead'
        QtMocHelpers::PropertyData<quint64>(101, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 22),
        // property 'processedSamples'
        QtMocHelpers::PropertyData<quint64>(102, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 22),
        // property 'frequencyHz'
        QtMocHelpers::PropertyData<double>(103, QMetaType::Double, QMC::DefaultPropertyFlags, 23),
        // property 'noteName'
        QtMocHelpers::PropertyData<QString>(104, QMetaType::QString, QMC::DefaultPropertyFlags, 23),
        // property 'midiNote'
        QtMocHelpers::PropertyData<int>(35, QMetaType::Int, QMC::DefaultPropertyFlags, 23),
        // property 'cents'
        QtMocHelpers::PropertyData<double>(36, QMetaType::Double, QMC::DefaultPropertyFlags, 23),
        // property 'pitchConfidence'
        QtMocHelpers::PropertyData<double>(105, QMetaType::Double, QMC::DefaultPropertyFlags, 23),
        // property 'voiced'
        QtMocHelpers::PropertyData<bool>(106, QMetaType::Bool, QMC::DefaultPropertyFlags, 23),
        // property 'onsetCount'
        QtMocHelpers::PropertyData<int>(107, QMetaType::Int, QMC::DefaultPropertyFlags, 24),
        // property 'lastOnsetSeconds'
        QtMocHelpers::PropertyData<double>(108, QMetaType::Double, QMC::DefaultPropertyFlags, 24),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Preset'
        QtMocHelpers::EnumData<enum Preset>(44, 44, QMC::EnumFlags{}).add({
            {  109, Preset::Singing },
            {  110, Preset::Clapping },
        }),
        // enum 'AnalysisMode'
        QtMocHelpers::EnumData<enum AnalysisMode>(47, 47, QMC::EnumFlags{}).add({
            {  111, AnalysisMode::SingingPitchOnly },
            {  112, AnalysisMode::ClappingOnsetOnly },
        }),
        // enum 'VoiceClass'
        QtMocHelpers::EnumData<enum VoiceClass>(50, 50, QMC::EnumFlags{}).add({
            {  113, VoiceClass::Soprano },
            {  114, VoiceClass::Alto },
            {  115, VoiceClass::Tenor },
            {  116, VoiceClass::Bass },
        }),
        // enum 'PitchMethod'
        QtMocHelpers::EnumData<enum PitchMethod>(53, 53, QMC::EnumFlags{}).add({
            {  117, PitchMethod::YinFft },
            {  118, PitchMethod::Yin },
            {  119, PitchMethod::YinFast },
            {  120, PitchMethod::MComb },
            {  121, PitchMethod::Schmitt },
            {  122, PitchMethod::SpecAcf },
            {  123, PitchMethod::FComb },
        }),
        // enum 'OnsetMethod'
        QtMocHelpers::EnumData<enum OnsetMethod>(56, 56, QMC::EnumFlags{}).add({
            {  124, OnsetMethod::Complex },
            {  125, OnsetMethod::Hfc },
            {  126, OnsetMethod::Energy },
            {  127, OnsetMethod::SpecFlux },
            {  128, OnsetMethod::Phase },
            {  129, OnsetMethod::SpecDiff },
            {  130, OnsetMethod::Kl },
            {  131, OnsetMethod::Mkl },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<IMicrophoneInputController, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Minuet::IMicrophoneInputController::staticMetaObject = { {
    QMetaObject::SuperData::link<IPlugin::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Minuet26IMicrophoneInputControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Minuet26IMicrophoneInputControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Minuet26IMicrophoneInputControllerE_t>.metaTypes,
    nullptr
} };

void Minuet::IMicrophoneInputController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IMicrophoneInputController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->runningChanged(); break;
        case 1: _t->statusChanged(); break;
        case 2: _t->captureTimeChanged(); break;
        case 3: _t->analysisPendingChanged(); break;
        case 4: _t->presetChanged(); break;
        case 5: _t->analysisModeChanged(); break;
        case 6: _t->voiceClassChanged(); break;
        case 7: _t->pitchMethodChanged(); break;
        case 8: _t->onsetMethodChanged(); break;
        case 9: _t->minimumPitchConfidenceChanged(); break;
        case 10: _t->pitchSilenceDbChanged(); break;
        case 11: _t->onsetThresholdChanged(); break;
        case 12: _t->inputGateLevelChanged(); break;
        case 13: _t->noiseFloorLevelChanged(); break;
        case 14: _t->noiseCalibrationActiveChanged(); break;
        case 15: _t->minimumOnsetStrengthChanged(); break;
        case 16: _t->requiredStablePitchFramesChanged(); break;
        case 17: _t->inputDeviceDescriptionChanged(); break;
        case 18: _t->inputDevicesChanged(); break;
        case 19: _t->inputDeviceAvailableChanged(); break;
        case 20: _t->inputDeviceIdChanged(); break;
        case 21: _t->audioLevelChanged(); break;
        case 22: _t->audioStatsChanged(); break;
        case 23: _t->pitchChanged(); break;
        case 24: _t->rhythmChanged(); break;
        case 25: _t->pitchDetected((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4]))); break;
        case 26: _t->onsetDetected((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 27: _t->inputAnalysisFinished(); break;
        case 28: _t->inputAnalysisFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 29: _t->setPreset((*reinterpret_cast<std::add_pointer_t<enum Preset>>(_a[1]))); break;
        case 30: _t->setAnalysisMode((*reinterpret_cast<std::add_pointer_t<enum AnalysisMode>>(_a[1]))); break;
        case 31: _t->setVoiceClass((*reinterpret_cast<std::add_pointer_t<enum VoiceClass>>(_a[1]))); break;
        case 32: _t->setPitchMethod((*reinterpret_cast<std::add_pointer_t<enum PitchMethod>>(_a[1]))); break;
        case 33: _t->setOnsetMethod((*reinterpret_cast<std::add_pointer_t<enum OnsetMethod>>(_a[1]))); break;
        case 34: _t->setMinimumPitchConfidence((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 35: _t->setPitchSilenceDb((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 36: _t->setOnsetThreshold((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 37: _t->setInputGateLevel((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 38: _t->setMinimumOnsetStrength((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 39: _t->setRequiredStablePitchFrames((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 40: _t->setInputDeviceId((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 41: _t->start(); break;
        case 42: _t->stop(); break;
        case 43: _t->resetInputAnalysisState(); break;
        case 44: _t->finalizeInputAnalysis(); break;
        case 45: _t->calibrateNoiseFloor(); break;
        case 46: { QString _r = _t->presetName((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 47: { QString _r = _t->voiceClassName((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 48: { QString _r = _t->pitchMethodName((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 49: { QString _r = _t->onsetMethodName((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (IMicrophoneInputController::*)()>(_a, &IMicrophoneInputController::runningChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (IMicrophoneInputController::*)()>(_a, &IMicrophoneInputController::statusChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (IMicrophoneInputController::*)()>(_a, &IMicrophoneInputController::captureTimeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (IMicrophoneInputController::*)()>(_a, &IMicrophoneInputController::analysisPendingChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (IMicrophoneInputController::*)()>(_a, &IMicrophoneInputController::presetChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (IMicrophoneInputController::*)()>(_a, &IMicrophoneInputController::analysisModeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (IMicrophoneInputController::*)()>(_a, &IMicrophoneInputController::voiceClassChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (IMicrophoneInputController::*)()>(_a, &IMicrophoneInputController::pitchMethodChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (IMicrophoneInputController::*)()>(_a, &IMicrophoneInputController::onsetMethodChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (IMicrophoneInputController::*)()>(_a, &IMicrophoneInputController::minimumPitchConfidenceChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (IMicrophoneInputController::*)()>(_a, &IMicrophoneInputController::pitchSilenceDbChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (IMicrophoneInputController::*)()>(_a, &IMicrophoneInputController::onsetThresholdChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (IMicrophoneInputController::*)()>(_a, &IMicrophoneInputController::inputGateLevelChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (IMicrophoneInputController::*)()>(_a, &IMicrophoneInputController::noiseFloorLevelChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (IMicrophoneInputController::*)()>(_a, &IMicrophoneInputController::noiseCalibrationActiveChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (IMicrophoneInputController::*)()>(_a, &IMicrophoneInputController::minimumOnsetStrengthChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (IMicrophoneInputController::*)()>(_a, &IMicrophoneInputController::requiredStablePitchFramesChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (IMicrophoneInputController::*)()>(_a, &IMicrophoneInputController::inputDeviceDescriptionChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (IMicrophoneInputController::*)()>(_a, &IMicrophoneInputController::inputDevicesChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (IMicrophoneInputController::*)()>(_a, &IMicrophoneInputController::inputDeviceAvailableChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (IMicrophoneInputController::*)()>(_a, &IMicrophoneInputController::inputDeviceIdChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (IMicrophoneInputController::*)()>(_a, &IMicrophoneInputController::audioLevelChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (IMicrophoneInputController::*)()>(_a, &IMicrophoneInputController::audioStatsChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (IMicrophoneInputController::*)()>(_a, &IMicrophoneInputController::pitchChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (IMicrophoneInputController::*)()>(_a, &IMicrophoneInputController::rhythmChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (IMicrophoneInputController::*)(double , int , double , double )>(_a, &IMicrophoneInputController::pitchDetected, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (IMicrophoneInputController::*)(double , double )>(_a, &IMicrophoneInputController::onsetDetected, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (IMicrophoneInputController::*)()>(_a, &IMicrophoneInputController::inputAnalysisFinished, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (IMicrophoneInputController::*)(const QString & )>(_a, &IMicrophoneInputController::inputAnalysisFailed, 28))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->running(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->status(); break;
        case 2: *reinterpret_cast<double*>(_v) = _t->analysisTimeSeconds(); break;
        case 3: *reinterpret_cast<double*>(_v) = _t->captureTimeSeconds(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->analysisPending(); break;
        case 5: *reinterpret_cast<enum Preset*>(_v) = _t->preset(); break;
        case 6: *reinterpret_cast<enum AnalysisMode*>(_v) = _t->analysisMode(); break;
        case 7: *reinterpret_cast<enum VoiceClass*>(_v) = _t->voiceClass(); break;
        case 8: *reinterpret_cast<enum PitchMethod*>(_v) = _t->pitchMethod(); break;
        case 9: *reinterpret_cast<enum OnsetMethod*>(_v) = _t->onsetMethod(); break;
        case 10: *reinterpret_cast<double*>(_v) = _t->minimumPitchConfidence(); break;
        case 11: *reinterpret_cast<double*>(_v) = _t->pitchSilenceDb(); break;
        case 12: *reinterpret_cast<double*>(_v) = _t->onsetThreshold(); break;
        case 13: *reinterpret_cast<double*>(_v) = _t->inputGateLevel(); break;
        case 14: *reinterpret_cast<double*>(_v) = _t->noiseFloorLevel(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->inputGateOpen(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->noiseCalibrationActive(); break;
        case 17: *reinterpret_cast<double*>(_v) = _t->minimumOnsetStrength(); break;
        case 18: *reinterpret_cast<int*>(_v) = _t->requiredStablePitchFrames(); break;
        case 19: *reinterpret_cast<int*>(_v) = _t->stablePitchFrameCount(); break;
        case 20: *reinterpret_cast<QString*>(_v) = _t->inputDeviceDescription(); break;
        case 21: *reinterpret_cast<QVariantList*>(_v) = _t->inputDevices(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->inputDeviceAvailable(); break;
        case 23: *reinterpret_cast<QString*>(_v) = _t->inputDeviceId(); break;
        case 24: *reinterpret_cast<double*>(_v) = _t->audioLevel(); break;
        case 25: *reinterpret_cast<double*>(_v) = _t->peakLevel(); break;
        case 26: *reinterpret_cast<quint64*>(_v) = _t->bytesRead(); break;
        case 27: *reinterpret_cast<quint64*>(_v) = _t->processedSamples(); break;
        case 28: *reinterpret_cast<double*>(_v) = _t->frequencyHz(); break;
        case 29: *reinterpret_cast<QString*>(_v) = _t->noteName(); break;
        case 30: *reinterpret_cast<int*>(_v) = _t->midiNote(); break;
        case 31: *reinterpret_cast<double*>(_v) = _t->cents(); break;
        case 32: *reinterpret_cast<double*>(_v) = _t->pitchConfidence(); break;
        case 33: *reinterpret_cast<bool*>(_v) = _t->voiced(); break;
        case 34: *reinterpret_cast<int*>(_v) = _t->onsetCount(); break;
        case 35: *reinterpret_cast<double*>(_v) = _t->lastOnsetSeconds(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 5: _t->setPreset(*reinterpret_cast<enum Preset*>(_v)); break;
        case 6: _t->setAnalysisMode(*reinterpret_cast<enum AnalysisMode*>(_v)); break;
        case 7: _t->setVoiceClass(*reinterpret_cast<enum VoiceClass*>(_v)); break;
        case 8: _t->setPitchMethod(*reinterpret_cast<enum PitchMethod*>(_v)); break;
        case 9: _t->setOnsetMethod(*reinterpret_cast<enum OnsetMethod*>(_v)); break;
        case 10: _t->setMinimumPitchConfidence(*reinterpret_cast<double*>(_v)); break;
        case 11: _t->setPitchSilenceDb(*reinterpret_cast<double*>(_v)); break;
        case 12: _t->setOnsetThreshold(*reinterpret_cast<double*>(_v)); break;
        case 13: _t->setInputGateLevel(*reinterpret_cast<double*>(_v)); break;
        case 17: _t->setMinimumOnsetStrength(*reinterpret_cast<double*>(_v)); break;
        case 18: _t->setRequiredStablePitchFrames(*reinterpret_cast<int*>(_v)); break;
        case 23: _t->setInputDeviceId(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Minuet::IMicrophoneInputController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Minuet::IMicrophoneInputController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Minuet26IMicrophoneInputControllerE_t>.strings))
        return static_cast<void*>(this);
    return IPlugin::qt_metacast(_clname);
}

int Minuet::IMicrophoneInputController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = IPlugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 50)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 50;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 50)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 50;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 36;
    }
    return _id;
}

// SIGNAL 0
void Minuet::IMicrophoneInputController::runningChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Minuet::IMicrophoneInputController::statusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Minuet::IMicrophoneInputController::captureTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Minuet::IMicrophoneInputController::analysisPendingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Minuet::IMicrophoneInputController::presetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Minuet::IMicrophoneInputController::analysisModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Minuet::IMicrophoneInputController::voiceClassChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Minuet::IMicrophoneInputController::pitchMethodChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Minuet::IMicrophoneInputController::onsetMethodChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Minuet::IMicrophoneInputController::minimumPitchConfidenceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Minuet::IMicrophoneInputController::pitchSilenceDbChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Minuet::IMicrophoneInputController::onsetThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Minuet::IMicrophoneInputController::inputGateLevelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void Minuet::IMicrophoneInputController::noiseFloorLevelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void Minuet::IMicrophoneInputController::noiseCalibrationActiveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void Minuet::IMicrophoneInputController::minimumOnsetStrengthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void Minuet::IMicrophoneInputController::requiredStablePitchFramesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void Minuet::IMicrophoneInputController::inputDeviceDescriptionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void Minuet::IMicrophoneInputController::inputDevicesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void Minuet::IMicrophoneInputController::inputDeviceAvailableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void Minuet::IMicrophoneInputController::inputDeviceIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void Minuet::IMicrophoneInputController::audioLevelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void Minuet::IMicrophoneInputController::audioStatsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void Minuet::IMicrophoneInputController::pitchChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void Minuet::IMicrophoneInputController::rhythmChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void Minuet::IMicrophoneInputController::pitchDetected(double _t1, int _t2, double _t3, double _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 26
void Minuet::IMicrophoneInputController::onsetDetected(double _t1, double _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1, _t2);
}

// SIGNAL 27
void Minuet::IMicrophoneInputController::inputAnalysisFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void Minuet::IMicrophoneInputController::inputAnalysisFailed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 28, nullptr, _t1);
}
QT_WARNING_POP
