/****************************************************************************
** Meta object code from reading C++ file 'exercisesessioncontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../minuet-26.08.0/src/app/exercisesessioncontroller.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'exercisesessioncontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Minuet25ExerciseSessionControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto Minuet::ExerciseSessionController::qt_create_metaobjectdata<qt_meta_tag_ZN6Minuet25ExerciseSessionControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Minuet::ExerciseSessionController",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "ExerciseSessionController is provided by Core",
        "sessionChanged",
        "",
        "activeExerciseChanged",
        "QVariantMap",
        "activeExercise",
        "selectedExerciseOptionsChanged",
        "QJsonArray",
        "selectedExerciseOptions",
        "resetForExercise",
        "clearUserAnswers",
        "availableAnswersModel",
        "QVariantList",
        "exercise",
        "answerModel",
        "QVariant",
        "answer",
        "colorForAnswerIndex",
        "index",
        "colors",
        "answerIndexForName",
        "answers",
        "answerName",
        "colorForAnswer",
        "availableAnswers",
        "answerPresentation",
        "rootPitch",
        "submittedAnswerFor",
        "option",
        "userAnswerFor",
        "selectedOptionCount",
        "rhythmPatternCount",
        "answerInstruction",
        "count",
        "isWrongSubmittedAnswer",
        "userAnswers",
        "correctAnswers",
        "position",
        "answersMatch",
        "expectedAnswers",
        "canShowSubmittedAnswerCorrection",
        "showSubmittedAnswerCorrection",
        "restoreSubmittedAnswerCorrection",
        "toggleSubmittedAnswerCorrection",
        "chooseAnswer",
        "canEditUserAnswers",
        "viewState",
        "animationRunning",
        "removeUserAnswerAt",
        "removeLastUserAnswer",
        "checkAnswers",
        "maximumExercises",
        "resetTest",
        "startTest",
        "stopTest",
        "recordTestScore",
        "score",
        "setActiveExercise",
        "randomlySelectExerciseOptions",
        "giveUpWithCorrectAnswers",
        "beginQuestion",
        "finishQuestionGeneration",
        "setSingleAnswerHighlight",
        "clearSingleAnswerHighlight",
        "currentAnswer",
        "answersAreRight",
        "isTest",
        "currentExercise",
        "showingCorrectAnswers",
        "correctedAnswerPosition",
        "highlightingSingleAnswer",
        "highlightedAnswerName",
        "statusText",
        "statusRole",
        "StatusRole",
        "chosenRootNote",
        "NeutralStatus",
        "PositiveStatus",
        "NegativeStatus"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sessionChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeExerciseChanged'
        QtMocHelpers::SignalData<void(QVariantMap)>(9, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'selectedExerciseOptionsChanged'
        QtMocHelpers::SignalData<void(QJsonArray)>(12, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Method 'resetForExercise'
        QtMocHelpers::MethodData<void()>(15, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'clearUserAnswers'
        QtMocHelpers::MethodData<void()>(16, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'availableAnswersModel'
        QtMocHelpers::MethodData<QVariantList(const QVariantMap &) const>(17, 8, QMC::AccessPublic, 0x80000000 | 18, {{
            { 0x80000000 | 10, 19 },
        }}),
        // Method 'answerModel'
        QtMocHelpers::MethodData<QVariantMap(const QVariant &) const>(20, 8, QMC::AccessPublic, 0x80000000 | 10, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Method 'colorForAnswerIndex'
        QtMocHelpers::MethodData<QString(int, const QVariantList &) const>(23, 8, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 24 }, { 0x80000000 | 18, 25 },
        }}),
        // Method 'answerIndexForName'
        QtMocHelpers::MethodData<int(const QVariantList &, const QString &) const>(26, 8, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 18, 27 }, { QMetaType::QString, 28 },
        }}),
        // Method 'colorForAnswer'
        QtMocHelpers::MethodData<QString(const QVariant &, const QVariantList &, const QVariantList &) const>(29, 8, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 21, 22 }, { 0x80000000 | 18, 30 }, { 0x80000000 | 18, 25 },
        }}),
        // Method 'answerPresentation'
        QtMocHelpers::MethodData<QVariantMap(const QVariantList &, int, const QVariantMap &, const QVariantList &, const QVariantList &) const>(31, 8, QMC::AccessPublic, 0x80000000 | 10, {{
            { 0x80000000 | 18, 27 }, { QMetaType::Int, 32 }, { 0x80000000 | 10, 19 }, { 0x80000000 | 18, 30 },
            { 0x80000000 | 18, 25 },
        }}),
        // Method 'submittedAnswerFor'
        QtMocHelpers::MethodData<QVariantMap(const QVariantMap &, const QVariantList &, const QVariantList &) const>(33, 8, QMC::AccessPublic, 0x80000000 | 10, {{
            { 0x80000000 | 10, 34 }, { 0x80000000 | 18, 30 }, { 0x80000000 | 18, 25 },
        }}),
        // Method 'userAnswerFor'
        QtMocHelpers::MethodData<QVariantMap(const QVariantMap &, int, const QVariantList &) const>(35, 8, QMC::AccessPublic, 0x80000000 | 10, {{
            { 0x80000000 | 10, 22 }, { QMetaType::Int, 24 }, { 0x80000000 | 18, 25 },
        }}),
        // Method 'selectedOptionCount'
        QtMocHelpers::MethodData<int(const QVariantMap &, int) const>(36, 8, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 10, 19 }, { QMetaType::Int, 37 },
        }}),
        // Method 'answerInstruction'
        QtMocHelpers::MethodData<QString(int) const>(38, 8, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 39 },
        }}),
        // Method 'isWrongSubmittedAnswer'
        QtMocHelpers::MethodData<bool(const QVariantList &, const QVariantList &, int) const>(40, 8, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 18, 41 }, { 0x80000000 | 18, 42 }, { QMetaType::Int, 43 },
        }}),
        // Method 'answersMatch'
        QtMocHelpers::MethodData<bool(const QVariantList &, const QVariantList &, int) const>(44, 8, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 18, 41 }, { 0x80000000 | 18, 42 }, { QMetaType::Int, 45 },
        }}),
        // Method 'canShowSubmittedAnswerCorrection'
        QtMocHelpers::MethodData<bool(int, const QVariantMap &, int, const QVariantList &) const>(46, 8, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 43 }, { 0x80000000 | 10, 19 }, { QMetaType::Int, 36 }, { 0x80000000 | 18, 42 },
        }}),
        // Method 'showSubmittedAnswerCorrection'
        QtMocHelpers::MethodData<void(int)>(47, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 43 },
        }}),
        // Method 'restoreSubmittedAnswerCorrection'
        QtMocHelpers::MethodData<void()>(48, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'toggleSubmittedAnswerCorrection'
        QtMocHelpers::MethodData<void(int, const QVariantMap &, int, const QVariantList &)>(49, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 43 }, { 0x80000000 | 10, 19 }, { QMetaType::Int, 36 }, { 0x80000000 | 18, 42 },
        }}),
        // Method 'chooseAnswer'
        QtMocHelpers::MethodData<bool(const QVariantMap &, int, int, const QVariantList &)>(50, 8, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 10, 22 }, { QMetaType::Int, 24 }, { QMetaType::Int, 36 }, { 0x80000000 | 18, 25 },
        }}),
        // Method 'canEditUserAnswers'
        QtMocHelpers::MethodData<bool(const QString &, int, bool) const>(51, 8, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 52 }, { QMetaType::Int, 36 }, { QMetaType::Bool, 53 },
        }}),
        // Method 'removeUserAnswerAt'
        QtMocHelpers::MethodData<bool(int)>(54, 8, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 43 },
        }}),
        // Method 'removeLastUserAnswer'
        QtMocHelpers::MethodData<bool()>(55, 8, QMC::AccessPublic, QMetaType::Bool),
        // Method 'checkAnswers'
        QtMocHelpers::MethodData<void(const QVariantList &, int, int)>(56, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 42 }, { QMetaType::Int, 45 }, { QMetaType::Int, 57 },
        }}),
        // Method 'resetTest'
        QtMocHelpers::MethodData<void()>(58, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'startTest'
        QtMocHelpers::MethodData<void()>(59, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'stopTest'
        QtMocHelpers::MethodData<void()>(60, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'recordTestScore'
        QtMocHelpers::MethodData<int(int, int)>(61, 8, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 62 }, { QMetaType::Int, 57 },
        }}),
        // Method 'setActiveExercise'
        QtMocHelpers::MethodData<void(const QVariantMap &)>(63, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Method 'randomlySelectExerciseOptions'
        QtMocHelpers::MethodData<void(int)>(64, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 36 },
        }}),
        // Method 'randomlySelectExerciseOptions'
        QtMocHelpers::MethodData<void()>(64, 8, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'giveUpWithCorrectAnswers'
        QtMocHelpers::MethodData<void(const QVariantList &, const QVariantList &, const QVariantList &, int)>(65, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 42 }, { 0x80000000 | 18, 30 }, { 0x80000000 | 18, 25 }, { QMetaType::Int, 45 },
        }}),
        // Method 'beginQuestion'
        QtMocHelpers::MethodData<void(int)>(66, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 57 },
        }}),
        // Method 'finishQuestionGeneration'
        QtMocHelpers::MethodData<void()>(67, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'setSingleAnswerHighlight'
        QtMocHelpers::MethodData<void(const QString &)>(68, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Method 'clearSingleAnswerHighlight'
        QtMocHelpers::MethodData<void()>(69, 8, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'currentAnswer'
        QtMocHelpers::PropertyData<int>(70, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'userAnswers'
        QtMocHelpers::PropertyData<QVariantList>(41, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'answersAreRight'
        QtMocHelpers::PropertyData<bool>(71, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'isTest'
        QtMocHelpers::PropertyData<bool>(72, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'currentExercise'
        QtMocHelpers::PropertyData<int>(73, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'showingCorrectAnswers'
        QtMocHelpers::PropertyData<bool>(74, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'correctedAnswerPosition'
        QtMocHelpers::PropertyData<int>(75, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'highlightingSingleAnswer'
        QtMocHelpers::PropertyData<bool>(76, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'highlightedAnswerName'
        QtMocHelpers::PropertyData<QString>(77, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'statusText'
        QtMocHelpers::PropertyData<QString>(78, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'statusRole'
        QtMocHelpers::PropertyData<enum StatusRole>(79, 0x80000000 | 80, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'activeExercise'
        QtMocHelpers::PropertyData<QVariantMap>(11, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'selectedExerciseOptions'
        QtMocHelpers::PropertyData<QJsonArray>(14, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'chosenRootNote'
        QtMocHelpers::PropertyData<uint>(81, QMetaType::UInt, QMC::DefaultPropertyFlags, 2),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'StatusRole'
        QtMocHelpers::EnumData<enum StatusRole>(80, 80, QMC::EnumFlags{}).add({
            {   82, StatusRole::NeutralStatus },
            {   83, StatusRole::PositiveStatus },
            {   84, StatusRole::NegativeStatus },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<ExerciseSessionController, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Minuet::ExerciseSessionController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Minuet25ExerciseSessionControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Minuet25ExerciseSessionControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Minuet25ExerciseSessionControllerE_t>.metaTypes,
    nullptr
} };

void Minuet::ExerciseSessionController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ExerciseSessionController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sessionChanged(); break;
        case 1: _t->activeExerciseChanged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 2: _t->selectedExerciseOptionsChanged((*reinterpret_cast<std::add_pointer_t<QJsonArray>>(_a[1]))); break;
        case 3: _t->resetForExercise(); break;
        case 4: _t->clearUserAnswers(); break;
        case 5: { QVariantList _r = _t->availableAnswersModel((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 6: { QVariantMap _r = _t->answerModel((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 7: { QString _r = _t->colorForAnswerIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: { int _r = _t->answerIndexForName((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 9: { QString _r = _t->colorForAnswer((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: { QVariantMap _r = _t->answerPresentation((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 11: { QVariantMap _r = _t->submittedAnswerFor((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 12: { QVariantMap _r = _t->userAnswerFor((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 13: { int _r = _t->selectedOptionCount((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 14: { QString _r = _t->answerInstruction((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->isWrongSubmittedAnswer((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->answersMatch((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->canShowSubmittedAnswerCorrection((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->showSubmittedAnswerCorrection((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->restoreSubmittedAnswerCorrection(); break;
        case 20: _t->toggleSubmittedAnswerCorrection((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[4]))); break;
        case 21: { bool _r = _t->chooseAnswer((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 22: { bool _r = _t->canEditUserAnswers((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 23: { bool _r = _t->removeUserAnswerAt((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 24: { bool _r = _t->removeLastUserAnswer();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->checkAnswers((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 26: _t->resetTest(); break;
        case 27: _t->startTest(); break;
        case 28: _t->stopTest(); break;
        case 29: { int _r = _t->recordTestScore((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 30: _t->setActiveExercise((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 31: _t->randomlySelectExerciseOptions((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 32: _t->randomlySelectExerciseOptions(); break;
        case 33: _t->giveUpWithCorrectAnswers((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 34: _t->beginQuestion((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 35: _t->finishQuestionGeneration(); break;
        case 36: _t->setSingleAnswerHighlight((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 37: _t->clearSingleAnswerHighlight(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ExerciseSessionController::*)()>(_a, &ExerciseSessionController::sessionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ExerciseSessionController::*)(QVariantMap )>(_a, &ExerciseSessionController::activeExerciseChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ExerciseSessionController::*)(QJsonArray )>(_a, &ExerciseSessionController::selectedExerciseOptionsChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->currentAnswer(); break;
        case 1: *reinterpret_cast<QVariantList*>(_v) = _t->userAnswers(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->answersAreRight(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isTest(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->currentExercise(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->showingCorrectAnswers(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->correctedAnswerPosition(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->highlightingSingleAnswer(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->highlightedAnswerName(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->statusText(); break;
        case 10: *reinterpret_cast<enum StatusRole*>(_v) = _t->statusRole(); break;
        case 11: *reinterpret_cast<QVariantMap*>(_v) = _t->activeExercise(); break;
        case 12: *reinterpret_cast<QJsonArray*>(_v) = _t->selectedExerciseOptions(); break;
        case 13: *reinterpret_cast<uint*>(_v) = _t->chosenRootNote(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 11: _t->setActiveExercise(*reinterpret_cast<QVariantMap*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Minuet::ExerciseSessionController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Minuet::ExerciseSessionController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Minuet25ExerciseSessionControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Minuet::ExerciseSessionController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 38)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 38;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 38)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 38;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void Minuet::ExerciseSessionController::sessionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Minuet::ExerciseSessionController::activeExerciseChanged(QVariantMap _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Minuet::ExerciseSessionController::selectedExerciseOptionsChanged(QJsonArray _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
